<?php

return [
    'number.decimals_separator' => ',',
    'number.thousands_separator' => '.',
    'None' => 'Nema',
    'Edit' => 'Uredi',
    'Remove' => 'Obriši',
    'Yes' => 'Da',
    'No' => 'Ne',
    'cancel' => 'odustani',
    'or' => 'ili',
    'Yellow' => 'Žuta',
    'Blue' => 'Plava',
    'Green' => 'Zelena',
    'Purple' => 'Ljubičasta',
    'Red' => 'Crvena',
    'Orange' => 'Narančasta',
    'Grey' => 'Siva',
    'Brown' => 'Smeđa',
    'Deep Orange' => 'Tamno narančasta',
    'Dark Grey' => 'Tamno siva',
    'Pink' => 'Roza',
    'Teal' => 'Tirkizna',
    'Cyan' => 'Cyan',
    'Lime' => 'Limun zelena',
    'Light Green' => 'Svijetlo zelena',
    'Amber' => 'Jantar',
    'Save' => 'Snimi',
    'Login' => 'Prijava',
    'Official website:' => 'Službena Web stranica:',
    'Unassigned' => 'Nedodijeljen',
    'View this task' => 'Pogledaj zadatak',
    'Remove user' => 'Makni korisnika',
    'Do you really want to remove this user: "%s"?' => 'Doista želiš maknuti korisnika: "%s"?',
    'All users' => 'Svi korisnici',
    'Username' => 'Korisnik',
    'Password' => 'Lozinka',
    'Administrator' => 'Administrator',
    'Sign in' => 'Prijava',
    'Users' => 'Korisnik',
    'Forbidden' => 'Zabranjeno',
    'Access Forbidden' => 'Zabranjen prostup',
    'Edit user' => 'Promijeni korisnika',
    'Logout' => 'Odjava',
    'Bad username or password' => 'Neispravno korisničko ime ili lozinka',
    'Edit project' => 'Promijeni projekt',
    'Name' => 'Naziv',
    'Projects' => 'Projekti',
    'No project' => 'Bez projekta',
    'Project' => 'Projekt',
    'Status' => 'Status',
    'Tasks' => 'Zadatak',
    'Board' => 'Ploča',
    'Actions' => 'Radnje',
    'Inactive' => 'Neaktivan',
    'Active' => 'Aktivan',
    'Unable to update this board.' => 'Nije moguće promijeniti ovu ploču.',
    'Disable' => 'Onemogući',
    'Enable' => 'Omogući',
    'New project' => 'Novi projekt',
    'Do you really want to remove this project: "%s"?' => 'Doista želiš maknuti ovaj projekt: "%s"?',
    'Remove project' => 'Makni projekt',
    'Edit the board for "%s"' => 'Promijeni ploču za "%s"',
    'Add a new column' => 'Dodaj novi stupac',
    'Title' => 'Naslov',
    'Assigned to %s' => 'Dodijeljen korisniku %s',
    'Remove a column' => 'Makni stupac',
    'Unable to remove this column.' => 'Ne mogu maknuti stupac.',
    'Do you really want to remove this column: "%s"?' => 'Doista želiš maknuti ovaj stupac: "%s"?',
    'Settings' => 'Postavke',
    'Application settings' => 'Postavke aplikacije',
    'Language' => 'Jezik',
    'Webhook token:' => 'Token :',
    'API token:' => 'Token za API',
    'Database size:' => 'Veličina baze :',
    'Download the database' => 'Preuzmi bazu',
    'Optimize the database' => 'Optimiziraj bazu',
    '(VACUUM command)' => '(naredba VACUUM)',
    '(Gzip compressed Sqlite file)' => '(Sqlite baza zapakirana Gzip-om)',
    'Close a task' => 'Zatvori zadatak',
    'Column' => 'Stupac',
    'Color' => 'Boja',
    'Assignee' => 'Dodijeli',
    'Create another task' => 'Dodaj idući zadatak',
    'New task' => 'Novi zadatak',
    'Open a task' => 'Otvori zadatak',
    'Do you really want to open this task: "%s"?' => 'Da li zaista želiš otvoriti zadatak: "%s"?',
    'Back to the board' => 'Natrag na ploču',
    'There is nobody assigned' => 'Nitko nije dodijeljen!',
    'Column on the board:' => 'Stupac na ploči:',
    'Close this task' => 'Zatvori ovaj zadatak',
    'Open this task' => 'Otvori ovaj zadatak',
    'There is no description.' => 'Bez opisa.',
    'Add a new task' => 'Dodaj zadatak',
    'The username is required' => 'Korisničko ime je obavezno',
    'The maximum length is %d characters' => 'Maksimalna dužina je %d znakova',
    'The minimum length is %d characters' => 'Minimalna dužina je %d znakova',
    'The password is required' => 'Lozinka je obavezna',
    'This value must be an integer' => 'Mora biti cijeli broj',
    'The username must be unique' => 'Korisničko ime mora biti jedinstveno',
    'The user id is required' => 'Oznaka korisnika je obavezna',
    'Passwords don\'t match' => 'Lozinke se ne podudaraju',
    'The confirmation is required' => 'Potvrda je obavezna',
    'The project is required' => 'Projekt je obavezan',
    'The id is required' => 'Oznaka je obavezna',
    'The project id is required' => 'Oznaka projekta je obavezna',
    'The project name is required' => 'Naziv projekta je obavezan',
    'The title is required' => 'Naslov je obavezan',
    'Settings saved successfully.' => 'Postavke su uspješno snimljene.',
    'Unable to save your settings.' => 'Nije moguće snimanje postavki.',
    'Database optimization done.' => 'Optimizacija baze je završena.',
    'Your project has been created successfully.' => 'Projekt je uspješno kreiran.',
    'Unable to create your project.' => 'Nije moguće kreiranje projekta.',
    'Project updated successfully.' => 'Projekt je uspješno promijenjen.',
    'Unable to update this project.' => 'Nije moguća dopuna projekta.',
    'Unable to remove this project.' => 'Nije moguće uklanjanje projekta.',
    'Project removed successfully.' => 'Projekt uspješno maknut.',
    'Project activated successfully.' => 'Projekt je uspješno aktiviran.',
    'Unable to activate this project.' => 'Nije moguće aktiviranje projekta.',
    'Project disabled successfully.' => 'Projekt je uspješno deaktiviran.',
    'Unable to disable this project.' => 'Nije moguće deaktiviranje projekta.',
    'Unable to open this task.' => 'Nije moguće otvaranje zadatka.',
    'Task opened successfully.' => 'Zadatak je uspješno otvoren.',
    'Unable to close this task.' => 'Nije moguće zatvaranje ovog zadatka.',
    'Task closed successfully.' => 'Zadatak je uspješno zatvoren.',
    'Unable to update your task.' => 'Nije moguća dopuna zadatka.',
    'Task updated successfully.' => 'Zadatak je uspješno dopunjen.',
    'Unable to create your task.' => 'Nije moguće kreiranje zadatka.',
    'Task created successfully.' => 'Zadatak je uspješno kreiran.',
    'User created successfully.' => 'Korisnik je uspješno kreiran',
    'Unable to create your user.' => 'Nije uspjelo kreiranje korisnika.',
    'User updated successfully.' => 'Korisnik je uspješno dopunjen.',
    'User removed successfully.' => 'Korisnik je uspješno maknut.',
    'Unable to remove this user.' => 'Nije moguće uklanjanje korisnika.',
    'Board updated successfully.' => 'Ploča uspješno dopunjena.',
    'Ready' => 'Spreman',
    'Backlog' => 'Nadolazeće',
    'Work in progress' => 'U radu',
    'Done' => 'Gotovo',
    'Application version:' => 'Verzija aplikacije:',
    'Id' => 'Rb',
    'Public link' => 'Javni link',
    'Timezone' => 'Vremenska zona',
    'Sorry, I didn\'t find this information in my database!' => 'Na žalost, nije pronađena informacija u bazi',
    'Page not found' => 'Strana nije pronađena',
    'Complexity' => 'Složenost',
    'Task limit' => 'Ograničenje zadatka',
    'Task count' => 'Broj zadataka',
    'User' => 'Korisnik',
    'Comments' => 'Komentari',
    'Comment is required' => 'Komentar je obavezan',
    'Comment added successfully.' => 'Komentar je uspješno dodan',
    'Unable to create your comment.' => 'Nije moguće kreiranje komentara',
    'Due Date' => 'Rok',
    'Invalid date' => 'Neispravan datum',
    'Automatic actions' => 'Automatske radnje',
    'Your automatic action has been created successfully.' => 'Uspješno kreirana automatska radnja',
    'Unable to create your automatic action.' => 'Nije moguće kreiranje automatske radnje',
    'Remove an action' => 'Obriši radnju',
    'Unable to remove this action.' => 'Nije moguće obrisati radnju',
    'Action removed successfully.' => 'Radnja obrisana',
    'Automatic actions for the project "%s"' => 'Radnje za automatizaciju projekta "%s"',
    'Add an action' => 'Dodaj radnju',
    'Event name' => 'Naziv događaja',
    'Action' => 'Radnja',
    'Event' => 'Događaj',
    'When the selected event occurs execute the corresponding action.' => 'Kad se dogodi odabrani događaj izvrši odgovarajuću radnju',
    'Next step' => 'Idući korak',
    'Define action parameters' => 'Definiraj parametre radnje',
    'Do you really want to remove this action: "%s"?' => 'Želite obrisati radnju "%s"?',
    'Remove an automatic action' => 'Obriši automatsku radnju',
    'Assign the task to a specific user' => 'Dodijeli zadatak određenom korisniku',
    'Assign the task to the person who does the action' => 'Dodijeli zadatak korisniku koji je napravio radnju',
    'Duplicate the task to another project' => 'Kopiraj zadatak u drugi projekt',
    'Move a task to another column' => 'Premjesti zadatak u drugi stupac',
    'Task modification' => 'Izman zadatka',
    'Task creation' => 'Kreiranje zadatka',
    'Closing a task' => 'Zatvaranja zadatka',
    'Assign a color to a specific user' => 'Dodijeli boju korisniku',
    'Position' => 'Pozicija',
    'Duplicate to project' => 'Kopiraj u drugi projekt',
    'Duplicate' => 'Napravi kopiju',
    'Link' => 'Poveznica',
    'Comment updated successfully.' => 'Komentar je uspješno dopunjen.',
    'Unable to update your comment.' => 'Nije moguće dopuniti komentar.',
    'Remove a comment' => 'Obriši komentar',
    'Comment removed successfully.' => 'Komentar je uspješno maknut.',
    'Unable to remove this comment.' => 'Nije uspjelo brisanje komentara.',
    'Do you really want to remove this comment?' => 'Da li da obrišem ovaj komentar?',
    'Current password for the user "%s"' => 'Trenutna lozinka za korisnika "%s"',
    'The current password is required' => 'Trenutna lozinka je obavezna',
    'Wrong password' => 'Pogrešna lozinka',
    'Unknown' => 'Nepoznat',
    'Last logins' => 'Zadnja prijava',
    'Login date' => 'Datum prijave',
    'Authentication method' => 'Metoda autorizacije',
    'IP address' => 'IP adresa',
    'User agent' => 'Browser',
    'Persistent connections' => 'Stalna konekcija',
    'No session.' => 'Nema sesije',
    'Expiration date' => 'Ističe',
    'Remember Me' => 'Zapamti me',
    'Creation date' => 'Datum kreiranja',
    'Everybody' => 'Svi',
    'Open' => 'Otvoreni',
    'Closed' => 'Zatvoreni',
    'Search' => 'Traži',
    'Nothing found.' => 'Ništa nije pronađeno',
    'Due date' => 'Rok',
    'Description' => 'Opis',
    '%d comments' => '%d komentara',
    '%d comment' => '%d komentar',
    'Email address invalid' => 'Pogrešan e-mail',
    'Your external account is not linked anymore to your profile.' => 'Vanjski korisnički račun više nije povezan sa vašim profilom.',
    'Unable to unlink your external account.' => 'Nije moguće maknuti vezu sa vanjskim korisničkim računom.',
    'External authentication failed' => 'Vanjska autorizacija nije uspjela',
    'Your external account is linked to your profile successfully.' => 'Vanjski korisnički račun je uspješno povezan sa vašim profilom.',
    'Email' => 'E-mail',
    'Task removed successfully.' => 'Zadatak uspješno maknut.',
    'Unable to remove this task.' => 'Nije moguće uklanjanje zadatka.',
    'Remove a task' => 'Makni zadatak',
    'Do you really want to remove this task: "%s"?' => 'Da li da obrišem zadatak "%s"?',
    'Assign automatically a color based on a category' => 'Automatski dodijeli boju po kategoriji',
    'Assign automatically a category based on a color' => 'Automatski dodijeli kategoriju po boji',
    'Task creation or modification' => 'Kreiranje ili promjena zadatka',
    'Category' => 'Kategorija',
    'Category:' => 'Kategorija:',
    'Categories' => 'Kategorije',
    'Your category has been created successfully.' => 'Uspješno kreirana kategorija.',
    'This category has been updated successfully.' => 'Kategorija uspješno dopunjena.',
    'Unable to update this category.' => 'Kategoriju nije moguće dopuniti.',
    'Remove a category' => 'Obriši kategoriju',
    'Category removed successfully.' => 'Kategorija je uspješno maknuta.',
    'Unable to remove this category.' => 'Nije moguće maknuti kategoriju.',
    'Category modification for the project "%s"' => 'Promjena kategorije za projekt "%s"',
    'Category Name' => 'Naziv kategorije',
    'Add a new category' => 'Dodaj novu kategoriju',
    'Do you really want to remove this category: "%s"?' => 'Doista želite maknuti kategoriju: "%s"?',
    'All categories' => 'Sve kategorije',
    'No category' => 'Bez kategorije',
    'The name is required' => 'Naziv je obavezan',
    'Remove a file' => 'Makni datoteku',
    'Unable to remove this file.' => 'Datoteku nije moguće maknuti.',
    'File removed successfully.' => 'Datoteka je uspješno maknuta.',
    'Attach a document' => 'Dodaj dokument',
    'Do you really want to remove this file: "%s"?' => 'Doista želite maknuti datoteku: "%s"?',
    'Attachments' => 'Prilozi',
    'Edit the task' => 'Promjena zadatka',
    'Add a comment' => 'Dodaj komentar',
    'Edit a comment' => 'Promjena komentara',
    'Summary' => 'Pregled',
    'Time tracking' => 'Praćenje vremena',
    'Estimate:' => 'Procjena:',
    'Spent:' => 'Potrošeno:',
    'Do you really want to remove this sub-task?' => 'Doista želite maknuti podzadatak?',
    'Remaining:' => 'Preostalo:',
    'hours' => 'sati',
    'estimated' => 'procjena',
    'Sub-Tasks' => 'Podzadaci',
    'Add a sub-task' => 'Dodaj podzadatak',
    'Original estimate' => 'Izvorna procjena',
    'Create another sub-task' => 'Dodaj novi podzadatak',
    'Time spent' => 'Potrošeno vremena',
    'Edit a sub-task' => 'Promijeni podzadatak',
    'Remove a sub-task' => 'Makni podzadatak',
    'The time must be a numeric value' => 'Vrijeme mora biti broj',
    'Todo' => 'Za rad',
    'In progress' => 'U radu',
    'Sub-task removed successfully.' => 'Podzadatak je uspješno maknut.',
    'Unable to remove this sub-task.' => 'Nije mouće maknuti ovaj podzadatak.',
    'Sub-task updated successfully.' => 'Podzadatak je uspješno dopunjen.',
    'Unable to update your sub-task.' => 'Nije moguće dopuniti ovaj podzadatak.',
    'Unable to create your sub-task.' => 'Nije moguće krerati ovaj podzadatak.',
    'Maximum size: ' => 'Maksimalna veličina: ',
    'Display another project' => 'Prikaži drugi projekt',
    'Created by %s' => 'Kreirao %s',
    'Tasks Export' => 'Izvoz zadataka',
    'Start Date' => 'Početni datum',
    'Execute' => 'Izvrši',
    'Task Id' => 'Identifikator Zadatka',
    'Creator' => 'Autor',
    'Modification date' => 'Datum promjene',
    'Completion date' => 'Datum kompletiranja',
    'Clone' => 'Iskopiraj',
    'Project cloned successfully.' => 'Projekt uspješno kopiran.',
    'Unable to clone this project.' => 'Nije moguće kopirati projekt.',
    'Enable email notifications' => 'Omogući obaveštenja e-mailom',
    'Task position:' => 'Pozicija zadatka:',
    'The task #%d has been opened.' => 'Zadatak #%d je otvoren.',
    'The task #%d has been closed.' => 'Zadatak #%d je zatvoren.',
    'Sub-task updated' => 'Podzadatak dopunjen',
    'Title:' => 'Naslov:',
    'Status:' => 'Status:',
    'Assignee:' => 'Dodijeljeno:',
    'Time tracking:' => 'Praćenje vremena: ',
    'New sub-task' => 'Novi Podzadatak',
    'New attachment added "%s"' => 'Novi prilog ubačen "%s"',
    'New comment posted by %s' => 'Novi komentar ostavio %s',
    'New comment' => 'Novi komentar',
    'Comment updated' => 'Komentar dopunjen',
    'New subtask' => 'Novi podzadatak',
    'I only want to receive notifications for these projects:' => 'Želim primati obavijesti samo za ove projekte:',
    'view the task on Kanboard' => 'Pregledaj zadatke',
    'Public access' => 'Javni pristup',
    'Disable public access' => 'Zabrani javni pristup',
    'Enable public access' => 'Dozvoli javni pristup',
    'Public access disabled' => 'Javni pristup onemogućen!',
    'Move the task to another project' => 'Premjesti zadatak u drugi projekt',
    'Move to project' => 'Premjesti u drugi projekt',
    'Do you really want to duplicate this task?' => 'Želite duplicirati ovaj zadatak?',
    'Duplicate a task' => 'Kopiraj zadatak',
    'External accounts' => 'Vanjski korisnički račun',
    'Account type' => 'Vrsta korisničkog računa',
    'Local' => 'Lokalno',
    'Remote' => 'Udaljeno',
    'Enabled' => 'Omogući',
    'Disabled' => 'Onemogući',
    'Login:' => 'Korisničko ime:',
    'Full Name:' => 'Ime i prezime:',
    'Email:' => 'E-mail:',
    'Notifications:' => 'Obavijesti:',
    'Notifications' => 'Obavijesti',
    'Account type:' => 'Vrsta korisničkog računa:',
    'Edit profile' => 'Promjena profila',
    'Change password' => 'Promjena lozinke',
    'Password modification' => 'Promjena lozinke',
    'External authentications' => 'Vanjske autorizacije',
    'Never connected.' => 'Bez spajanja.',
    'No external authentication enabled.' => 'Nisu omogućene vanjske autorizacije.',
    'Password modified successfully.' => 'Uspješna promjena lozinke.',
    'Unable to change the password.' => 'Nije moguće promijeniti lozinku.',
    'Change category' => 'Promijeni kategoriju',
    '%s updated the task %s' => '%s dopunio zadatak %s',
    '%s opened the task %s' => '%s otvorio zadatak %s',
    '%s moved the task %s to the position #%d in the column "%s"' => '%s pomaknuo zadatak %s na poziciju #%d u stupcu "%s"',
    '%s moved the task %s to the column "%s"' => '%s pomaknuo zadatak %s u stupac "%s"',
    '%s created the task %s' => '%s je kreirao zadatak %s',
    '%s closed the task %s' => '%s je zatvorio zadatak %s',
    '%s created a subtask for the task %s' => '%s je kreirao podzadatak zadatka %s',
    '%s updated a subtask for the task %s' => '%s je dopunio podzadatak zadatka %s',
    'Assigned to %s with an estimate of %s/%sh' => 'Dodijeljen korisniku %s uz procjenu vremena %s/%sh',
    'Not assigned, estimate of %sh' => 'Nije dodijeljen, procijenjeno vrijeme %sh',
    '%s updated a comment on the task %s' => '%s je dopunio komentar zadatka %s',
    '%s commented the task %s' => '%s je komentirao zadatak %s',
    '%s\'s activity' => 'Aktivnosti %s',
    'RSS feed' => 'RSS kanal',
    '%s updated a comment on the task #%d' => '%s je dopunio komentar zadatka #%d',
    '%s commented on the task #%d' => '%s je komentirao zadatak #%d',
    '%s updated a subtask for the task #%d' => '%s je dopunio podzadatak zadatka #%d',
    '%s created a subtask for the task #%d' => '%s je kreirao podzadatak zadatka #%d',
    '%s updated the task #%d' => '%s je dopunio zadatak #%d',
    '%s created the task #%d' => '%s je kreirao zadatak #%d',
    '%s closed the task #%d' => '%s je zatvorio zadatak #%d',
    '%s opened the task #%d' => '%s je otvorio zadatak #%d',
    'Activity' => 'Aktivnosti',
    'Default values are "%s"' => 'Inicijalne vrijednosti su: "%s"',
    'Default columns for new projects (Comma-separated)' => 'Inicijalni stupci za novi projekt (odvojeni zarezom)',
    'Task assignee change' => 'Promjena dodjele zadatka',
    '%s changed the assignee of the task #%d to %s' => '%s promijenio kome je dodijeljen zadatak #%d na %s',
    '%s changed the assignee of the task %s to %s' => '%s promijenio kome je dodijeljen zadatak %s na %s',
    'New password for the user "%s"' => 'Nova lozinka za korisnika "%s"',
    'Choose an event' => 'Odaberi događaj',
    'Create a task from an external provider' => 'Kreiraj zadatak iz vanjskog izvora',
    'Change the assignee based on an external username' => 'Dodijeli zadatak ovisno o vanjskom imenu korisnika',
    'Change the category based on an external label' => 'Dodijeli zadatak ovisno o vanjskoj oznaci',
    'Reference' => 'Referenca',
    'Label' => 'Oznaka',
    'Database' => 'Baza podataka',
    'About' => 'O programu',
    'Database driver:' => 'Upravljački program baze podataka:',
    'Board settings' => 'Podešavanje ploče',
    'Webhook settings' => 'Webhook postavke',
    'Reset token' => 'Resetiraj token',
    'API endpoint:' => 'API pristupna točka:',
    'Refresh interval for personal board' => 'Osvježavanje privatnih ploča',
    'Refresh interval for public board' => 'Osvježavanje javnih ploča',
    'Task highlight period' => 'Koliko dugo je zadatak istaknut',
    'Period (in second) to consider a task was modified recently (0 to disable, 2 days by default)' => 'Vrijeme (u sekundama) koliko se zadatak smatra nedavno mijenjanim (0 isključi, inicijalno 2 dana)',
    'Frequency in second (60 seconds by default)' => 'Učestalost u sekundama (inicijalno 60 sekundi)',
    'Frequency in second (0 to disable this feature, 10 seconds by default)' => 'Učestalost u sekundama (inicijalno 10 sekundi)',
    'Application URL' => 'URL adresa aplikacije',
    'Token regenerated.' => 'Token wygenerowany ponownie.',
    'Date format' => 'Oblik datuma',
    'ISO format is always accepted, example: "%s" and "%s"' => 'Format ISO je uvijek prihvatljiv, npr: "%s", "%s"',
    'New personal project' => 'Novi privatni projekt',
    'This project is personal' => 'Ovo je privatni projekt',
    'Add' => 'Dodaj',
    'Start date' => 'Datum početka',
    'Time estimated' => 'Procjena vremena',
    'There is nothing assigned to you.' => 'Ništa vam nije dodijeljeno',
    'My tasks' => 'Moji zadaci',
    'Activity stream' => 'Tijek aktivnosti',
    'Dashboard' => 'Nadzorna ploča',
    'Confirmation' => 'Potvrda',
    'Webhooks' => 'Webhook-ovi',
    'API' => 'API',
    'Create a comment from an external provider' => 'Kreirajte komentar za vanjskog pružatelja',
    'Project management' => 'Uređivanje projekata',
    'Columns' => 'Stupci',
    'Task' => 'Zadaci',
    'Percentage' => 'Postotak',
    'Number of tasks' => 'Broj zadataka',
    'Task distribution' => 'Podjela zadataka',
    'Analytics' => 'Analiza',
    'Subtask' => 'Podzadatak',
    'User repartition' => 'Zaduženja korisnika',
    'Clone this project' => 'Kopiraj projekt',
    'Column removed successfully.' => 'Stupac je uspješno maknut.',
    'Not enough data to show the graph.' => 'Nedovoljno podataka za grafikon.',
    'Previous' => 'Prethodni',
    'The id must be an integer' => 'RB mora biti cijeli broj',
    'The project id must be an integer' => 'RB projekta mora biti cijeli broj',
    'The status must be an integer' => 'Status mora biti cijeli broj',
    'The subtask id is required' => 'RB podzadatka je obavezan',
    'The subtask id must be an integer' => 'RB podzadatka mora biti cijeli broj',
    'The task id is required' => 'RB zadatka je obavezan',
    'The task id must be an integer' => 'RB zadatka mora biti cijeli broj',
    'The user id must be an integer' => 'RB korisnika mora biti cijeli broj',
    'This value is required' => 'Ova vrijednost je obavezna',
    'This value must be numeric' => 'Ova vrijednost mora biti broj',
    'Unable to create this task.' => 'Nije moguće kreirati zadatak.',
    'Cumulative flow diagram' => 'Kumulativni dijagram toka',
    'Daily project summary' => 'Dnevni sažetak projekta',
    'Daily project summary export' => 'Izvoz dnevnog sažetka projekta',
    'Exports' => 'Izvoz',
    'This export contains the number of tasks per column grouped per day.' => 'Ovaj izvoz sadrži broj zadataka po stupcu grupirano po danima.',
    'Active swimlanes' => 'Aktivne staze',
    'Add a new swimlane' => 'Dodaj novu stazu',
    'Default swimlane' => 'Inicijalna staza',
    'Do you really want to remove this swimlane: "%s"?' => 'Želite maknuti ovu stazu: "%s"?',
    'Inactive swimlanes' => 'Neaktivne staze',
    'Remove a swimlane' => 'Makni stazu',
    'Swimlane modification for the project "%s"' => 'Promjena staza za projekt "%s"',
    'Swimlane removed successfully.' => 'Staza uspješno maknuta.',
    'Swimlanes' => 'Staze',
    'Swimlane updated successfully.' => 'Staza je uspješno dopunjena.',
    'Unable to remove this swimlane.' => 'Nije moguće maknuti ovu stazu',
    'Unable to update this swimlane.' => 'Nije moguća dopuna ove staze',
    'Your swimlane has been created successfully.' => 'Vaša staza je uspješno kreirana.',
    'Example: "Bug, Feature Request, Improvement"' => 'Npr: "Greška, Zahtjev za promjenom, Poboljšanje"',
    'Default categories for new projects (Comma-separated)' => 'Inicijalne kategorije projekta',
    'Integrations' => 'Integracije',
    'Integration with third-party services' => 'Integracija sa uslugama vanjskih servisa',
    'Subtask Id' => 'RB podzadatka',
    'Subtasks' => 'Podzadaci',
    'Subtasks Export' => 'Izvoz podzadataka',
    'Task Title' => 'Naslov zadatka',
    'Untitled' => 'Bez naslova',
    'Application default' => 'Inicijalne postavke aplikacje',
    'Language:' => 'Jezik:',
    'Timezone:' => 'Vremenska zona:',
    'All columns' => 'Svi stupci',
    'Next' => 'Idući',
    '#%d' => '#%d',
    'All swimlanes' => 'Sve staze',
    'All colors' => 'Sve boje',
    'Moved to column %s' => 'Pomaknut u stupac %s',
    'User dashboard' => 'Korisnička nadzorna ploča',
    'Allow only one subtask in progress at the same time for a user' => 'Dozvoli samo jedan podzadatak "u tijeku" po korisniku',
    'Edit column "%s"' => 'Uredi stupac "%s"',
    'Select the new status of the subtask: "%s"' => 'Izaberi novi status za podzadatak: "%s"',
    'Subtask timesheet' => 'Tabela vremena za podzadatke',
    'There is nothing to show.' => 'Nema podataka',
    'Time Tracking' => 'Praćenje vremena',
    'You already have one subtask in progress' => 'Već imate jedan podzadatak "u radu"',
    'Which parts of the project do you want to duplicate?' => 'Koje dijelove projekta želite kopirati?',
    'Disallow login form' => 'Zabrani formu prijave',
    'Start' => 'Početak',
    'End' => 'Kraj',
    'Task age in days' => 'Starost zadatka u danima',
    'Days in this column' => 'Dana u ovom stupcu',
    '%dd' => '%dd',
    'Add a new link' => 'Dodaj novu vezu',
    'Do you really want to remove this link: "%s"?' => 'Doista želite maknuti ovu vezu: "%s"?',
    'Do you really want to remove this link with task #%d?' => 'Doista želite maknuti ovu vezu sa zadatkom #%d?',
    'Field required' => 'Polje je obavezno',
    'Link added successfully.' => 'Veza je uspješno dodana.',
    'Link updated successfully.' => 'Veza je uspješno dopunjena.',
    'Link removed successfully.' => 'Veza je uspješno maknuta.',
    'Link labels' => 'Oznake poveznica',
    'Link modification' => 'Promjena veze',
    'Opposite label' => 'Suprotna oznaka',
    'Remove a link' => 'Makni vezu',
    'The labels must be different' => 'Oznake moraju biti različite',
    'There is no link.' => 'Ne postoji veza',
    'This label must be unique' => 'Ova oznaka mora biti jedinstvena',
    'Unable to create your link.' => 'Nije moguće kreirati vezu.',
    'Unable to update your link.' => 'Nije moguće dopuniti vezu.',
    'Unable to remove this link.' => 'Nije moguće maknuti vezu.',
    'relates to' => 'povezan sa',
    'blocks' => 'blokira',
    'is blocked by' => 'je blokiran od',
    'duplicates' => 'duplicira',
    'is duplicated by' => 'je duplikat od',
    'is a child of' => 'je dijete od',
    'is a parent of' => 'je roditelj od',
    'targets milestone' => 'cilj ključne točke',
    'is a milestone of' => 'je ključna točka od',
    'fixes' => 'popravlja',
    'is fixed by' => 'je popravljen od',
    'This task' => 'Ovaj zadatak',
    '<1h' => '<1s',
    '%dh' => '%ds',
    'Expand tasks' => 'Proširi zadatke',
    'Collapse tasks' => 'Skupi zadatke',
    'Expand/collapse tasks' => 'Proširi/skupi zadatke',
    'Close dialog box' => 'Zatvori dijalog',
    'Submit a form' => 'Pošalji obrazac',
    'Board view' => 'Pregled ploče',
    'Keyboard shortcuts' => 'Prečice tipkovnice',
    'Open board switcher' => 'Otvori promjenu ploče',
    'Application' => 'Aplikacija',
    'Compact view' => 'Kompaktni prikaz',
    'Horizontal scrolling' => 'Horizontalno listanje',
    'Compact/wide view' => 'Kompaktni/široki pregled',
    'Currency' => 'Valuta',
    'Personal project' => 'Osobni projekt',
    'AUD - Australian Dollar' => 'AUD - Australski dolar',
    'CAD - Canadian Dollar' => 'CAD - Kanadski dolar',
    'CHF - Swiss Francs' => 'CHF - Švicarski franak',
    'Custom Stylesheet' => 'Prilagođeni CSS',
    'EUR - Euro' => 'EUR - Euro',
    'GBP - British Pound' => 'GBP - Britanska funta',
    'INR - Indian Rupee' => 'INR - Indijski rupi',
    'JPY - Japanese Yen' => 'JPY - Japanski yen',
    'NZD - New Zealand Dollar' => 'NZD - Novozelandski dolar',
    'PEN - Peruvian Sol' => 'PEN - Peruanski Sol',
    'RSD - Serbian dinar' => 'RSD - Srpski dinar',
    'CNY - Chinese Yuan' => 'CNY - Kineski jen',
    'USD - US Dollar' => 'USD - Američki dolar',
    'VES - Venezuelan Bolívar' => 'VES - Venecuelanski bolivar',
    'Destination column' => 'Odredišni stupac',
    'Move the task to another column when assigned to a user' => 'Pomakni zadatak u drugi stupac kada se dodijeli izvršitelju',
    'Move the task to another column when assignee is cleared' => 'Pomakni zadatak u drugi stupac kada se makne izvršitelj',
    'Source column' => 'Izvorni stupac',
    'Transitions' => 'Pomicanja',
    'Executer' => 'Izvršitelj',
    'Time spent in the column' => 'Vrijeme provedeno u stupcu',
    'Task transitions' => 'Pomicanja zadatka',
    'Task transitions export' => 'Izvezi prelaze zadataka',
    'This report contains all column moves for each task with the date, the user and the time spent for each transition.' => 'Ovaj izvještaj sadrži sva pomicanja unutar stupaca za svaki zadatak sa datumom, korisnikom i potrošenim vremenom za svako pomicanje.',
    'Currency rates' => 'Tečajna lista',
    'Rate' => 'Tečaj',
    'Change reference currency' => 'Promijeni osnovnu valutu',
    'Reference currency' => 'Referentna valuta',
    'The currency rate has been added successfully.' => 'Tečaj je uspješno dodan.',
    'Unable to add this currency rate.' => 'Nije moguće dodati ovaj tečaj.',
    'Webhook URL' => 'Webhook URL',
    '%s removed the assignee of the task %s' => '%s je maknuo/la izvršitelja zadatka %s',
    'Information' => 'Informacije',
    'Check two factor authentication code' => 'Provjerite kod za dvo-faktorsku autorizaciju',
    'The two factor authentication code is not valid.' => 'Kod za dvo-faktorsku autorizaciju nije ispravan.',
    'The two factor authentication code is valid.' => 'Kod za dvo-faktorsku autorizaciju je ispravan',
    'Code' => 'Kod',
    'Two factor authentication' => 'Dvo-faktorska autorizacija',
    'This QR code contains the key URI: ' => 'Ovaj QR kod sadrži ključni URL:',
    'Check my code' => 'Provjeri moj kod',
    'Secret key: ' => 'Tajni ključ: ',
    'Test your device' => 'Testiraj svoj uređaj',
    'Assign a color when the task is moved to a specific column' => 'Dodijeli boju kada je zadatak pomaknut u odabrani stupac',
    '%s via Kanboard' => '%s pomoću Kanboard',
    'Burndown chart' => 'Preostalo posla / vrijeme',
    'This chart show the task complexity over the time (Work Remaining).' => 'Ovaj graf pokazuje kompleksnost zadataka tokom vremena (Preostalo posla)',
    'Screenshot taken %s' => 'Slika ekrana preuzeta %s',
    'Add a screenshot' => 'Dodaj sliku ekrana',
    'Take a screenshot and press CTRL+V or ⌘+V to paste here.' => 'Uzmi sliku ekrana i pritisni CTRL+V ili ⌘+V za zalijepiti.',
    'Screenshot uploaded successfully.' => 'Slika ekrana uspješno dodana.',
    'SEK - Swedish Krona' => 'SEK - Švedska kruna',
    'Identifier' => 'Oznaka',
    'Disable two factor authentication' => 'Onemogućite dvo-faktorsku autorizaciju',
    'Do you really want to disable the two factor authentication for this user: "%s"?' => 'Doista želite onemogućiti dvo-faktorsku autorizaciju za ovog korisnika: "%s"?',
    'Edit link' => 'Uredi vezu',
    'Start to type task title...' => 'Počnite pisati naslov zadatka...',
    'A task cannot be linked to itself' => 'Zadatak ne može biti povezan sa samim sobom',
    'The exact same link already exists' => 'Identična veza već postoji',
    'Recurrent task is scheduled to be generated' => 'Ponavljajući zadatak je pripremljen za kreiranje',
    'Score' => 'Bodovi',
    'The identifier must be unique' => 'Identifikator mora biti jedinstven',
    'This linked task id doesn\'t exists' => 'Povezani RB zadatka ne postoji',
    'This value must be alphanumeric' => 'Ova vrijednost mora biti znakovno-brojčana',
    'Edit recurrence' => 'Promjena ponavljanja',
    'Generate recurrent task' => 'Kreiraj ponavljajući zadatak',
    'Trigger to generate recurrent task' => 'Okidač koji kreira ponavljajući zadatak',
    'Factor to calculate new due date' => 'Faktor za računanje novog roka završetka',
    'Timeframe to calculate new due date' => 'Vremenski okvir za računanje novog roka završetka',
    'Base date to calculate new due date' => 'Početni datum za računanje novog roka završetka',
    'Action date' => 'Datum radnje',
    'Base date to calculate new due date: ' => 'Početni datum za računanje novog roka završetka: ',
    'This task has created this child task: ' => 'Zadatak je kreirao ovaj zadatak-dijete: ',
    'Day(s)' => 'Dan/i',
    'Existing due date' => 'Postojeći rok završetka',
    'Factor to calculate new due date: ' => 'Faktor za računanje novog roka završetka: ',
    'Month(s)' => 'Mjesec(i)',
    'This task has been created by: ' => 'Ovaj zadatak je kreirao: ',
    'Recurrent task has been generated:' => 'Ponavljajući zadatak je kreirao:',
    'Timeframe to calculate new due date: ' => 'Vremenski okvir za računanje novog roka završetka:',
    'Trigger to generate recurrent task: ' => 'Okidač za kreiranje ponavljajućeg zadatka',
    'When task is closed' => 'Kada je zadatak zatvoren',
    'When task is moved from first column' => 'Kada je zadatak pomaknut iz prvog stupca',
    'When task is moved to last column' => 'Kada je zadatak pomaknut u poslednji stupac',
    'Year(s)' => 'Godina/e',
    'Project settings' => 'Postavke projekta',
    'Automatically update the start date' => 'Automatski dopuni početni datum',
    'iCal feed' => 'iCal kanal',
    'Preferences' => 'Postavke',
    'Security' => 'Sigurnost',
    'Two factor authentication disabled' => 'Dvo-faktorska autorizacija je onemogućena',
    'Two factor authentication enabled' => 'Dvo-faktorska autorizacija je omogućena',
    'Unable to update this user.' => 'Nije moguće dopuniti ovog korisnika',
    'There is no user management for personal projects.' => 'Nema upravljanja korisnicima kod osobnih projekata.',
    'User that will receive the email' => 'Korisnik koji će primiti e-mail',
    'Email subject' => 'Predmet e-mail-a',
    'Date' => 'Datum',
    'Add a comment log when moving the task between columns' => 'Dodaj komentar u dnevnik kada se zadatak pomakne iz jednog stupca u drugi',
    'Move the task to another column when the category is changed' => 'Pomakni zadatak u drugi stupac kada se promijeni kategorija',
    'Send a task by email to someone' => 'Pošalji zadatak nekome putem e-mail-a',
    'Reopen a task' => 'Ponovo otvori zadatak',
    'Notification' => 'Obavijesti',
    '%s moved the task #%d to the first swimlane' => '%s je pomaknuo/la zadatak #%d u prvu stazu',
    'Swimlane' => 'Staza',
    '%s moved the task %s to the first swimlane' => '%s je pomaknuo/la zadatak %s u prvu stazu',
    '%s moved the task %s to the swimlane "%s"' => '%s je pomaknuo/la zadatak %s u stazu "%s"',
    'This report contains all subtasks information for the given date range.' => 'Ovaj izvještaj sadrži sve informacije o podzadacima u zadanom razdoblju',
    'This report contains all tasks information for the given date range.' => 'Ovaj izvještaj sadrži sve informacije o zadacima u zadanom razdoblju',
    'Project activities for %s' => 'Aktivnosti projekta za %s',
    'view the board on Kanboard' => 'Pregledaj ploču',
    'The task has been moved to the first swimlane' => 'Zadatak je pomaknut u prvu stazu',
    'The task has been moved to another swimlane:' => 'Zadatak je pomaknut u drugu stazu:',
    'New title: %s' => 'Novi naslov: %s',
    'The task is not assigned anymore' => 'Ovaj zadatak više nema izvršitelja',
    'New assignee: %s' => 'Novi izvršitelj: %s',
    'There is no category now' => 'Sada nema kategorije',
    'New category: %s' => 'Nova kategorija: %s',
    'New color: %s' => 'Nova boja: %s',
    'New complexity: %d' => 'Nova kompleksnost: %d',
    'The due date has been removed' => 'Rok završetka je maknut',
    'There is no description anymore' => 'Nema više opisa',
    'Recurrence settings has been modified' => 'Promjena podešenja za ponavljajuće zadatke',
    'Time spent changed: %sh' => 'Potrošeno vrijeme je promijenjeno: %sh',
    'Time estimated changed: %sh' => 'Procjena vremena je promijenjena: %sh',
    'The field "%s" has been updated' => 'Polje "%s" je dopunjeno',
    'The description has been modified:' => 'Promjena opisa:',
    'Do you really want to close the task "%s" as well as all subtasks?' => 'Doista želite zatvoriti zadatak "%s" i sve podzadatke?',
    'I want to receive notifications for:' => 'Želim primati obavijesti za:',
    'All tasks' => 'Sve zadatke',
    'Only for tasks assigned to me' => 'Samo zadatke koji su mi dodijeljeni',
    'Only for tasks created by me' => 'Samo zadatke koje sam kreirao',
    'Only for tasks created by me and tasks assigned to me' => 'Samo zadatke koji su mi dodijeljeni i koje sam kreirao',
    '%%Y-%%m-%%d' => '%%d.%%m.%%Y',
    'Total for all columns' => 'Ukupno za sve stupce',
    'You need at least 2 days of data to show the chart.' => 'Da bi se prikazao grafikon trebaju postojati podaci barem dva dana unatrag.',
    '<15m' => '<15m',
    '<30m' => '<30m',
    'Stop timer' => 'Zaustavi timer',
    'Start timer' => 'Pokreni timer',
    'My activity stream' => 'Tijek mojih aktivnosti',
    'Search tasks' => 'Pretraživanje zadataka',
    'Reset filters' => 'Obriši filtere',
    'My tasks due tomorrow' => 'Moji zadaci sa rokom sutra',
    'Tasks due today' => 'Zadaci sa rokom danas',
    'Tasks due tomorrow' => 'Zadaci sa rokom sutra',
    'Tasks due yesterday' => 'Zadaci sa rokom jučer',
    'Closed tasks' => 'Zatvoreni zadaci',
    'Open tasks' => 'Otvoreni zadaci',
    'Not assigned' => 'Nije dodijeljeno',
    'View advanced search syntax' => 'Pogledaj naprednu sintaksu pretraživanja',
    'Overview' => 'Pregled',
    'Board/Calendar/List view' => 'Pregled Ploče/Kalendara/Liste',
    'Switch to the board view' => 'Prebacivanje na prikaz ploče',
    'Switch to the list view' => 'Prebacivanje na prikaz liste',
    'Go to the search/filter box' => 'Idi na polje za pretragu / filter',
    'There is no activity yet.' => 'Još uvijek nema aktivnosti.',
    'No tasks found.' => 'Zadaci nisu pronađeni.',
    'Keyboard shortcut: "%s"' => 'Prečica tipkovnice: "%s"',
    'List' => 'Lista',
    'Filter' => 'Filter',
    'Advanced search' => 'Napredno pretraživanje',
    'Example of query: ' => 'Primjer upita: ',
    'Search by project: ' => 'Pretraživanje po projektu: ',
    'Search by column: ' => 'Pretraživanje po stupcu: ',
    'Search by assignee: ' => 'Pretraživanje kome je dodijeljeno: ',
    'Search by color: ' => 'Pretraživanje po boji: ',
    'Search by category: ' => 'Pretraživanje po kategoriji: ',
    'Search by description: ' => 'Pretraživanje po opisu: ',
    'Search by due date: ' => 'Pretraživanje po datumskom roku: ',
    'Average time spent in each column' => 'Prosek potrošenog vremena u svakom stupcu',
    'Average time spent' => 'Prosjek potrošenog vremena',
    'This chart shows the average time spent in each column for the last %d tasks.' => 'Ovaj graf pokazuje prosjek potrošenog vremena u svakom stupcu za zadnjih %d zadataka.',
    'Average Lead and Cycle time' => 'Prosječno vrijeme realizacije i izvođenja',
    'Average lead time: ' => 'Prosječno vrijeme realizacije: ',
    'Average cycle time: ' => 'Prosječno vrijeme ciklusa: ',
    'Cycle Time' => 'Vrijeme ciklusa',
    'Lead Time' => 'Vrijeme realizacije',
    'This chart shows the average lead and cycle time for the last %d tasks over the time.' => 'Ova grafika prikazuje prosjek vremena realizacije i ciklusa za zadnjih %d zadataka tijekom vremena.',
    'Average time into each column' => 'Prosječno vrijeme u svakom stupcu',
    'Lead and cycle time' => 'Vrijeme realizacije i ciklusa',
    'Lead time: ' => 'Vrijeme realizacije: ',
    'Cycle time: ' => 'Vrijeme ciklusa: ',
    'Time spent in each column' => 'Potrošeno vrijeme u svakom stupcu',
    'The lead time is the duration between the task creation and the completion.' => 'Vrijeme realizacije je trajanje od otvaranja do završetka zadatka.',
    'The cycle time is the duration between the start date and the completion.' => 'Vrijeme ciklusa je trajanje od početka do završetka zadatka.',
    'If the task is not closed the current time is used instead of the completion date.' => 'Ako zadatak nije završen, trenutno vrijeme se koristi umesto datuma završetka.',
    'Set the start date automatically' => 'Automatski postavi početno vrijeme',
    'Edit Authentication' => 'Uredi Autorizacije',
    'Remote user' => 'Udaljeni korisnik',
    'Remote users do not store their password in Kanboard database, examples: LDAP, Google and Github accounts.' => 'Za udaljenog korisnika lozinka se ne čuva u Kanboard bazi, npr: LDAP, Google i Github korisnički računi.',
    'If you check the box "Disallow login form", credentials entered in the login form will be ignored.' => 'Ako je označeno polje "Zabrani formu prijave" unos pristupnih podataka u formi prijave biti će ignoriran.',
    'Default task color' => 'Inicijalna boja zadataka',
    'This feature does not work with all browsers.' => 'Ova funckionalnost ne radi na svim Web preglednicima.',
    'There is no destination project available.' => 'Nije dostupan niti jedan odredišni projekt.',
    'Trigger automatically subtask time tracking' => 'Automatsko pokretanje evidencije vremena za podzadatke',
    'Include closed tasks in the cumulative flow diagram' => 'Uključi zatvorene zadatke u kumulativni dijagram toka',
    'Current swimlane: %s' => 'Trenutna staza: %s',
    'Current column: %s' => 'Trenutni stupac: %s',
    'Current category: %s' => 'Trenutna kategorija: %s',
    'no category' => 'bez kategorije',
    'Current assignee: %s' => 'Trenutni izvršitelj: %s',
    'not assigned' => 'nije dodijeljeno',
    'Author:' => 'Autor:',
    'contributors' => 'suradnici',
    'License:' => 'Licenca:',
    'License' => 'Licenca',
    'Enter the text below' => 'Upišite tekst ispod',
    'Start date:' => 'Početno vrijeme:',
    'Due date:' => 'Rok:',
    'People who are project managers' => 'Osobe koji su manageri projekta',
    'People who are project members' => 'Osobe koje su članovi projekta',
    'NOK - Norwegian Krone' => 'NOK - Norveška kruna',
    'Show this column' => 'Prikaži ovaj stupac',
    'Hide this column' => 'Sakrij ovaj stupac',
    'End date' => 'Datum završetka',
    'Users overview' => 'Pregled korisnika',
    'Members' => 'Članovi',
    'Shared project' => 'Dijeljeni projekt',
    'Project managers' => 'Manageri projekta',
    'Projects list' => 'Lista projekata',
    'End date:' => 'Datum završetka:',
    'Change task color when using a specific task link' => 'Promijeni boju kada se koristi određena vrsta veze na zadatku',
    'Task link creation or modification' => 'Veza na zadatku je kreirana ili promijenjena',
    'Milestone' => 'Ključna točka',
    'Reset the search/filter box' => 'Resetiraj polje za pretragu/filtere',
    'Documentation' => 'Dokumentacija',
    'Author' => 'Autor',
    'Version' => 'Verzija',
    'Plugins' => 'Dodaci',
    'There is no plugin loaded.' => 'Nema učitanih dodataka.',
    'My notifications' => 'Moje obavijesti',
    'Custom filters' => 'Prilagođeni filteri',
    'Your custom filter has been created successfully.' => 'Prilagođeni filter je uspješno kreiran.',
    'Unable to create your custom filter.' => 'Nije moguće kreirati prilagođeni filter.',
    'Custom filter removed successfully.' => 'Prilagođeni filter je uspješno maknut.',
    'Unable to remove this custom filter.' => 'Nije moguće maknuti prilagođeni filter.',
    'Edit custom filter' => 'Uredi prilagođeni filter',
    'Your custom filter has been updated successfully.' => 'Prilagođeni filter je uspješno dopunjen.',
    'Unable to update custom filter.' => 'Nije moguće dopuniti prilagođeni filter',
    'Web' => 'Web',
    'New attachment on task #%d: %s' => 'Novi privitak na zadatku #%d: %s',
    'New comment on task #%d' => 'Novi komentar na zadatku #%d',
    'Comment updated on task #%d' => 'Dopunjen komentar na zadatku #%d',
    'New subtask on task #%d' => 'Novi podzadatak na zadatku #%d',
    'Subtask updated on task #%d' => 'Podzadatak dopunjen na zadatku #%d',
    'New task #%d: %s' => 'Novi zadatak #%d: %s',
    'Task updated #%d' => 'Zadatak dopunjen #%d',
    'Task #%d closed' => 'Zadatak #%d zatvoren',
    'Task #%d opened' => 'Zadatak #%d otvoren',
    'Column changed for task #%d' => 'Promijenjen stupac za zadatak #%d',
    'New position for task #%d' => 'Nova pozicija za zadatak #%d',
    'Swimlane changed for task #%d' => 'Staza izmjenjena za zadatak #%d',
    'Assignee changed on task #%d' => 'Izvršitelj je promijenjen na zadatku #%d',
    '%d overdue tasks' => '%d zadataka kasni',
    'No notification.' => 'Nema novih obavijesti.',
    'Mark all as read' => 'Označi sve kao pročitano',
    'Mark as read' => 'Označi kao pročitano',
    'Total number of tasks in this column across all swimlanes' => 'Ukupan broj zadataka u ovom stupcu u svim stazama',
    'Collapse swimlane' => 'Skupi stazu',
    'Expand swimlane' => 'Proširi stazu',
    'Add a new filter' => 'Dodaj novi filter',
    'Share with all project members' => 'Podijeli sa svim članovima projekta',
    'Shared' => 'Podijeljeno',
    'Owner' => 'Vlasnik',
    'Unread notifications' => 'Nepročitane obavijesti',
    'Notification methods:' => 'Vrste obavijesti:',
    'Unable to read your file' => 'Nije moguće pročitati datoteku',
    '%d task(s) have been imported successfully.' => '%d zadataka uspješno uvezeno.',
    'Nothing has been imported!' => 'Ništa nije uvezeno!',
    'Import users from CSV file' => 'Uvezi korisnike putem CSV datoteke',
    '%d user(s) have been imported successfully.' => '%d korisnika je uspješno uvezeno.',
    'Comma' => 'Zarez',
    'Semi-colon' => 'Točka-zarez',
    'Tab' => 'Tab',
    'Vertical bar' => 'Vertikalna traka',
    'Double Quote' => 'Dvostruki navodnici',
    'Single Quote' => 'Jednostruki navodnici',
    '%s attached a file to the task #%d' => '%s dodao/la je novu datoteku u zadatak %d',
    'There is no column or swimlane activated in your project!' => 'Nema stupca ili aktivne staze u vašem projektu!',
    'Append filter (instead of replacement)' => 'Dodaj filter (umesto zamjene postojećeg)',
    'Append/Replace' => 'Dodaj/Zamijeni',
    'Append' => 'Dodaj',
    'Replace' => 'Zamijeni',
    'Import' => 'Uvoz',
    'Change sorting' => 'Promijeni sortiranje',
    'Tasks Importation' => 'Uvoz zadataka',
    'Delimiter' => 'Graničnik',
    'Enclosure' => 'Prilog',
    'CSV File' => 'CSV datoteka',
    'Instructions' => 'Uputstva',
    'Your file must use the predefined CSV format' => 'Vaša datoteka mora koristiti predefinirani CSV format',
    'Your file must be encoded in UTF-8' => 'Vaša datoteka mora koristiti UTF-8 kodiranje',
    'The first row must be the header' => 'Prvi red mora biti zaglavlje',
    'Duplicates are not verified for you' => 'Duplikati se ne provjeravaju (morate sami)',
    'The due date must use the ISO format: YYYY-MM-DD' => 'Datum roka završetka mora biti u ISO formatu: YYYY-MM-DD',
    'Download CSV template' => 'Preuzmi CSV predložak',
    'No external integration registered.' => 'Nije zabilježena niti jedna vanjska integracija.',
    'Duplicates are not imported' => 'Duplikati nisu uveženi',
    'Usernames must be lowercase and unique' => 'Korisnička imena moraju biti napisana malim slovima i jedinstvena',
    'Passwords will be encrypted if present' => 'Lozinke (ako postoje) će biti kriptirane',
    '%s attached a new file to the task %s' => '%s je dodao datoteku za zadatak %s',
    'Link type' => 'Tip veze',
    'Assign automatically a category based on a link' => 'Automatsko dodjeljivanje kategorije bazirano na vezi',
    'BAM - Konvertible Mark' => 'BAM - Konvertibilna marka',
    'Assignee Username' => 'Korisničko ime izvršitelja',
    'Assignee Name' => 'Ime izvršitelja',
    'Groups' => 'Grupe',
    'Members of %s' => 'Članovi u %s',
    'New group' => 'Nova grupa',
    'Group created successfully.' => 'Grupa uspješno kreirana.',
    'Unable to create your group.' => 'Nije moguće kreirati grupu.',
    'Edit group' => 'Uredi grupu',
    'Group updated successfully.' => 'Grupa uspješno dopunjena.',
    'Unable to update your group.' => 'Nije moguće dopuniti grupu',
    'Add group member to "%s"' => 'Dodaj člana u grupu "%s"',
    'Group member added successfully.' => 'Uspješno dodan član grupe.',
    'Unable to add group member.' => 'Nije moguće dodati člana grupi.',
    'Remove user from group "%s"' => 'Makni korisnika iz grupe "%s"',
    'User removed successfully from this group.' => 'Korisnik uspješno maknut iz grupe.',
    'Unable to remove this user from the group.' => 'Nije moguće maknuti korisnika iz grupe.',
    'Remove group' => 'Makni grupu',
    'Group removed successfully.' => 'Grupa je uspješno maknuta.',
    'Unable to remove this group.' => 'Nije moguće maknuti grupu.',
    'Project Permissions' => 'Prava na projektu',
    'Manager' => 'Manager',
    'Project Manager' => 'Manager projekta',
    'Project Member' => 'Član projekta',
    'Project Viewer' => 'Promatrač projekta',
    'Your account is locked for %d minutes' => 'Vaš korisnički račun je zaključan idućih %d minuta',
    'Invalid captcha' => 'Pogrešna captcha',
    'The name must be unique' => 'Ime mora biti jedinstveno',
    'View all groups' => 'Pregled svih grupa',
    'There is no user available.' => 'Nema dostupnih korisnika.',
    'Do you really want to remove the user "%s" from the group "%s"?' => 'Doista želite maknuti korisnika "%s" iz grupe "%s"?',
    'There is no group.' => 'Nema grupe',
    'Add group member' => 'Dodaj člana grupe',
    'Do you really want to remove this group: "%s"?' => 'Doista želite da maknuti ovu grupu: "%s"?',
    'There is no user in this group.' => 'Trenutno nema korisnika u grupi.',
    'Permissions' => 'Prava',
    'Allowed Users' => 'Dozvoljeni korisnici',
    'No specific user has been allowed.' => 'Nije dozvoljeno niti jednom korisniku.',
    'Role' => 'Uloga',
    'Enter user name...' => 'Upiši korisničko ime...',
    'Allowed Groups' => 'Dozvoljene grupe',
    'No group has been allowed.' => 'Nije dozvoljeno niti jednoj grupi.',
    'Group' => 'Grupa',
    'Group Name' => 'Ime grupe',
    'Enter group name...' => 'Upiši ime grupe...',
    'Role:' => 'Uloga:',
    'Project members' => 'Članovi projekta',
    '%s mentioned you in the task #%d' => '%s vas je spomenuo/la u zadatku #%d',
    '%s mentioned you in a comment on the task #%d' => '%s vas je spomenuo/la u komentaru zadatka #%d',
    'You were mentioned in the task #%d' => 'Spomenuti ste u zadatku #%d',
    'You were mentioned in a comment on the task #%d' => 'Spomenuti ste u komntaru od zadatka #%d',
    'Estimated hours: ' => 'Procijenjeno sati:',
    'Actual hours: ' => 'Stvarno sati:',
    'Hours Spent' => 'Potrošeno sati:',
    'Hours Estimated' => 'Sati procijenjeno',
    'Estimated Time' => 'Procijenjeno vrijeme',
    'Actual Time' => 'Stvarno Vrijeme',
    'Estimated vs actual time' => 'Procijenjeno / stvarno vrijeme',
    'RUB - Russian Ruble' => 'RUB - Ruska rublja',
    'Assign the task to the person who does the action when the column is changed' => 'Dodijeli zadatak osobi koja izvrši radnju promjene stupca',
    'Close a task in a specific column' => 'Zatvori zadatak u određenom stupcu',
    'Time-based One-time Password Algorithm' => 'Algoritam vremenski bazirane jednokratne lozinke',
    'Two-Factor Provider: ' => 'Izdavač dvofaktorske prijave:',
    'Disable two-factor authentication' => 'Onemogući dvofaktorsku autorizaciju',
    'Enable two-factor authentication' => 'Omogući dvofaktorsku autorizaciju',
    'There is no integration registered at the moment.' => 'Trenutno nije registrirana niti jedna integracija.',
    'Password Reset for Kanboard' => 'Promjena lozinke za Kanboard',
    'Forgot password?' => 'Zaboravili ste lozinku?',
    'Enable "Forget Password"' => 'Omogući opciju "Zaboravljena lozinka"',
    'Password Reset' => 'Promjena lozinke',
    'New password' => 'Nova lozinka',
    'Change Password' => 'Promijeni lozinku',
    'To reset your password click on this link:' => 'Za promjenu lozinke kliknite na ovaj link:',
    'Last Password Reset' => 'Zadnja promjena lozinke',
    'The password has never been reinitialized.' => 'Lozinka nikada nije bila mijenjana.',
    'Creation' => 'Napravljeno',
    'Expiration' => 'Ističe',
    'Password reset history' => 'Povijest promjena lozinke',
    'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Svi zadaci stupca "%s" i staze "%s" su uspješno zatvoreni.',
    'Do you really want to close all tasks of this column?' => 'Doista želite zatvoriti sve zadatke ovog stupca?',
    '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d zadatak/a u stupcu "%s" i stazi "%s" će biti zatvoreno.',
    'Close all tasks in this column and this swimlane' => 'Zatvori sve zadatke ovog stupca',
    'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Niti jedan dodatak nije registrirao metodu za obavijesti o projektu. U korisničkom profilu i dalje možete urediti pojedinačne obavijesti.',
    'My dashboard' => 'Moja nadzorna ploča',
    'My profile' => 'Moj profil',
    'Project owner: ' => 'Vlasnik projekta: ',
    'The project identifier is optional and must be alphanumeric, example: MYPROJECT.' => 'Oznaka projekta je opcija i mora biti slovno-brojčana, npr. MOJPROJEKT1',
    'Project owner' => 'Vlasnik projekta',
    'Personal projects do not have users and groups management.' => 'Osobni projekti nemaju upravljanje korisnicima i grupama.',
    'There is no project member.' => 'Nema članova projekta.',
    'Priority' => 'Prioritet',
    'Task priority' => 'Prioritet zadataka',
    'General' => 'Općenito',
    'Dates' => 'Datumi',
    'Default priority' => 'Inicijalni prioritet',
    'Lowest priority' => 'Najmanji prioritet',
    'Highest priority' => 'Najveći prioritet',
    'Close a task when there is no activity' => 'Zatvori zadatak kada nema aktivnosti',
    'Duration in days' => 'Trajanje u danima',
    'Send email when there is no activity on a task' => 'Pošalji e-mail kada nema aktivnosti na zadatku',
    'Unable to fetch link information.' => 'Ne mogu dohvatiti informacije o vezi.',
    'Daily background job for tasks' => 'Dnevni poslovi u pozadini za zadatke',
    'Auto' => 'Automatski',
    'Related' => 'Povezan',
    'Attachment' => 'Privitak',
    'Web Link' => 'Web link',
    'External links' => 'Vanjske veze',
    'Add external link' => 'Dodaj vanjsku vezu',
    'Type' => 'Vrsta',
    'Dependency' => 'Zavisnost',
    'Add internal link' => 'Dodaj unutarnju vezu',
    'Add a new external link' => 'Dodaj novu vanjsku vezu',
    'Edit external link' => 'Uredi vanjsku vezu',
    'External link' => 'Vanjska veza',
    'Copy and paste your link here...' => 'Kopirajte i zalijepite ovdje vašu vezu...',
    'URL' => 'URL',
    'Internal links' => 'Unutarnje veze',
    'Assign to me' => 'Dodijeli meni',
    'Me' => 'Ja',
    'Do not duplicate anything' => 'Ništa ne dupliraj',
    'Projects management' => 'Uređivanje projekata',
    'Users management' => 'Upravljanje korisnicima',
    'Groups management' => 'Upravljanje grupama',
    'Create from another project' => 'Napravi iz drugog projekta',
    'open' => 'otvoren',
    'closed' => 'zatvoren',
    'Priority:' => 'Prioritet:',
    'Reference:' => 'Referenca:',
    'Complexity:' => 'Kompleksnost:',
    'Swimlane:' => 'Staza:',
    'Column:' => 'Stupac:',
    'Position:' => 'Pozicija:',
    'Creator:' => 'Napravio:',
    'Time estimated:' => 'Procjena vremena:',
    '%s hours' => '%s sati',
    'Time spent:' => 'Potrošeno vrijeme:',
    'Created:' => 'Kreirano:',
    'Modified:' => 'Promjenjeno:',
    'Completed:' => 'Završeno:',
    'Started:' => 'Započeto:',
    'Moved:' => 'Pomaknuto:',
    'Task #%d' => 'Zadatak #%d',
    'Time format' => 'Oblik vremena',
    'Start date: ' => 'Početni datum:',
    'End date: ' => 'Datum završetka:',
    'New due date: ' => 'Novi rok završetka:',
    'Start date changed: ' => 'Početni datum promijenjen: ',
    'Disable personal projects' => 'Onemogući privatne projekte',
    'Do you really want to remove this custom filter: "%s"?' => 'Doista želite maknuti ovaj prilagođeni filter "%s"?',
    'Remove a custom filter' => 'Makni prilagođeni filter',
    'User activated successfully.' => 'Korisnik uspješno aktiviran.',
    'Unable to enable this user.' => 'Nije moguće aktivirati ovog korisnika.',
    'User disabled successfully.' => 'Korisnik uspješno deaktiviran.',
    'Unable to disable this user.' => 'Nije moguće deaktivirati ovog korisnika.',
    'All files have been uploaded successfully.' => 'Sve datoteke su uspješno poslane.',
    'The maximum allowed file size is %sB.' => 'Maksimalna dozvoljena veličina datoteke je %sB.',
    'Drag and drop your files here' => 'Povucite i ovdje spustite datoteke',
    'choose files' => 'izaberite datoteke',
    'View profile' => 'Pregledaj profil',
    'Two Factor' => 'Dva faktora',
    'Disable user' => 'Deaktiviraj korisnika',
    'Do you really want to disable this user: "%s"?' => 'Doista želite deaktivirati ovog korisnika: "%s"?',
    'Enable user' => 'Aktiviraj korisnika',
    'Do you really want to enable this user: "%s"?' => 'Doista želite aktivirati ovog korisnika: "%s"?',
    'Download' => 'Preuzimanje',
    'Uploaded: %s' => 'Poslano: %s',
    'Size: %s' => 'Veličina: %s',
    'Uploaded by %s' => 'Poslao %s',
    'Filename' => 'Ime datoteke',
    'Size' => 'Veličina',
    'Column created successfully.' => 'Stupac uspješno napravljen.',
    'Another column with the same name exists in the project' => 'Već postoji stupac sa istim imenom u ovom projektu.',
    'Default filters' => 'Inicijalni filteri',
    'Your board doesn\'t have any columns!' => 'Tvoja ploča nema niti jedan stupac!',
    'Change column position' => 'Promijeni poziciju stupca',
    'Switch to the project overview' => 'Prebaci na pregled projekta',
    'User filters' => 'Fliteri korisnika',
    'Category filters' => 'Fliteri kategorija',
    'Upload a file' => 'Pošalji datoteku',
    'View file' => 'Pogledaj datoteku',
    'Last activity' => 'Zadnja aktivnost',
    'Change subtask position' => 'Promijeni poziciju podzadatka',
    'This value must be greater than %d' => 'Ova vrijednost mora biti veća od %d',
    'Another swimlane with the same name exists in the project' => 'Već postoji staza sa istim imenom u ovom projektu',
    'Example: https://example.kanboard.org/ (used to generate absolute URLs)' => 'Primjer: https://primjer.kanboard.org/ (koristi se za stvaranje apsolutnih URL adresa)',
    'Actions duplicated successfully.' => 'Radnje uspješno duplirane.',
    'Unable to duplicate actions.' => 'Nije moguće duplirati radnje.',
    'Add a new action' => 'Dodaj novu radnju',
    'Import from another project' => 'Uvezi iz drugog projekta',
    'There is no action at the moment.' => 'Trenutno nema radnji.',
    'Import actions from another project' => 'Uvezi radnje iz drugog projekta',
    'There is no available project.' => 'Trenutno nema dostupnih projekata.',
    'Local File' => 'Lokalna datoteka',
    'Configuration' => 'Uređivanje',
    'PHP version:' => 'Verzija PHP-a:',
    'PHP SAPI:' => 'PHP SAPI:',
    'OS version:' => 'Verzija operativnog sustava:',
    'Database version:' => 'Verzija baze podataka:',
    'Browser:' => 'Web preglednik:',
    'Task view' => 'Pregled zadataka',
    'Edit task' => 'Uredi zadatak',
    'Edit description' => 'Uredi opis',
    'New internal link' => 'Nova unutarnja veza',
    'Display list of keyboard shortcuts' => 'Prikaži listu prečica na tipkovnici',
    'Avatar' => 'Avatar',
    'Upload my avatar image' => 'Pošalji moju avatar sliku',
    'Remove my image' => 'Makni moju sliku',
    'The OAuth2 state parameter is invalid' => 'Parametar stanja OAuth2 nije ispravan',
    'User not found.' => 'Korisnik nije pronađen.',
    'Search in activity stream' => 'Pretraživanje u tijeku aktivnosti',
    'My activities' => 'Moje aktivnosti',
    'Activity until yesterday' => 'Aktivnosti do jučer',
    'Activity until today' => 'Aktivnosti do danas',
    'Search by creator: ' => 'Pretraživanje tko je kreirao: ',
    'Search by creation date: ' => 'Pretraživanje po datumu kreiranja: ',
    'Search by task status: ' => 'Pretraživanje po statusu zadatka: ',
    'Search by task title: ' => 'Pretraživanje po naslovu zadatka: ',
    'Activity stream search' => 'Pretraživanje tijeka aktivnosti',
    'Projects where "%s" is manager' => 'Projekti gde je "%s" manager',
    'Projects where "%s" is member' => 'Projekti gde je "%s" član',
    'Open tasks assigned to "%s"' => 'Otvoreni zadaci dodijeljeni "%s"',
    'Closed tasks assigned to "%s"' => 'Zatvoreni zadaci dodijeljeni "%s"',
    'Assign automatically a color based on a priority' => 'Automatski dodijeli boju ovisno o prioritetu',
    'Overdue tasks for the project(s) "%s"' => 'Zadaci koji kasne za projekt/e "%s"',
    'Upload files' => 'Pošalji datoteke',
    'Installed Plugins' => 'Instalirani dodaci',
    'Plugin Directory' => 'Folder dodataka',
    'Plugin installed successfully.' => 'Dodatak je uspješno instaliran.',
    'Plugin updated successfully.' => 'Dodatak je uspješno dopunjen.',
    'Plugin removed successfully.' => 'Dodatak uspješno maknut.',
    'Subtask converted to task successfully.' => 'Podzadatak uspješno pretvoren u zadatak.',
    'Unable to convert the subtask.' => 'Nije moguće pretvoriti podzadatak.',
    'Unable to extract plugin archive.' => 'Nije moguće raspakirati arhivu dodatka.',
    'Plugin not found.' => 'Dodatak nije pronađen.',
    'You don\'t have the permission to remove this plugin.' => 'Nemate pravo za micanje ovog dodatka.',
    'Unable to download plugin archive.' => 'Nije moguće preuzeti arhivu dodatka.',
    'Unable to write temporary file for plugin.' => 'Nije moguće zapisati privremenu datoteku za dodatak.',
    'Unable to open plugin archive.' => 'Nije moguće otvoriti arhivu dodatka.',
    'There is no file in the plugin archive.' => 'Nema datoteke u arhivi dodatka.',
    'Create tasks in bulk' => 'Masovno kreiranja zadataka',
    'Your Kanboard instance is not configured to install plugins from the user interface.' => 'Ovaj Kanboard nije namješten za instaliranje dodataka kroz korisničko sučelje.',
    'There is no plugin available.' => 'Nema dostupnih dodataka.',
    'Install' => 'Instaliraj',
    'Update' => 'Dopuni',
    'Up to date' => 'Ažurno',
    'Not available' => 'Nije dostupno',
    'Remove plugin' => 'Makni dodatak',
    'Do you really want to remove this plugin: "%s"?' => 'Doista želite maknuti ovaj dodatak: "%s"?',
    'Uninstall' => 'Deinstaliraj',
    'Listing' => 'Popis',
    'Metadata' => 'Meta-podaci',
    'Manage projects' => 'Uređivanje projekata',
    'Convert to task' => 'Pretvori u zadatak',
    'Convert sub-task to task' => 'Pretvori podzadatak u zadatak',
    'Do you really want to convert this sub-task to a task?' => 'Doista želite pretvoriti podzadatak u zadatak?',
    'My task title' => 'Naslov zadatka',
    'Enter one task by line.' => 'Upiši jedan zadatak u svakom redu.',
    'Number of failed login:' => 'Broj neuspješnih prijava:',
    'Account locked until:' => 'Korisnički račun zaključan do:',
    'Email settings' => 'E-mail postavke',
    'Email sender address' => 'E-mail adresa pošiljatelja',
    'Email transport' => 'Način slanja e-maila',
    'Webhook token' => 'Webhook token',
    'Project tags management' => 'Upravljanje oznakama projekta',
    'Tag created successfully.' => 'Oznaka uspješno kreirana.',
    'Unable to create this tag.' => 'Nije moguće kreirati oznaku.',
    'Tag updated successfully.' => 'Oznaka uspješno dopunjena.',
    'Unable to update this tag.' => 'Nije moguće dopuniti ovu oznaku.',
    'Tag removed successfully.' => 'Oznaka uspješno maknuta.',
    'Unable to remove this tag.' => 'Nije moguće maknuti ovu oznaku.',
    'Global tags management' => 'Globalno upravljanje oznakama.',
    'Tags' => 'Oznake',
    'Tags management' => 'Uređivanje oznaka',
    'Add new tag' => 'Dodaj novu oznaku',
    'Edit a tag' => 'Uređivanje oznake',
    'Project tags' => 'Oznake projekta',
    'There is no specific tag for this project at the moment.' => 'Trenutno nema oznaka za ovaj projekt.',
    'Tag' => 'Oznaka',
    'Remove a tag' => 'Brisanje oznake',
    'Do you really want to remove this tag: "%s"?' => 'Doista želite obrisati oznaku: "%s"?',
    'Global tags' => 'Globalne oznake',
    'There is no global tag at the moment.' => 'Trenutno nema globalno definiranih oznaka.',
    'This field cannot be empty' => 'Ovo polje ne može biti prazno',
    'Close a task when there is no activity in a specific column' => 'Zatvori zadatak kada nema aktivnosti u odabranom stupcu',
    '%s removed a subtask for the task #%d' => '%s je maknuo podzadatak od zadataka #%d',
    '%s removed a comment on the task #%d' => '%s je maknuo/la komentar na zadatku #%d',
    'Comment removed on task #%d' => 'Komentar je maknut na zadatku #%d',
    'Subtask removed on task #%d' => 'Podzadatak je maknut na zadatku #%d',
    'Hide tasks in this column in the dashboard' => 'Sakrijte zadatke u ovom stupcu na kontrolnoj ploči',
    '%s removed a comment on the task %s' => '%s je maknuo/la komentar za zadatak %s',
    '%s removed a subtask for the task %s' => '%s je maknuo podzadatak od zadataka #%s',
    'Comment removed' => 'Komentar maknut',
    'Subtask removed' => 'Podzadatak maknut',
    '%s set a new internal link for the task #%d' => '%s je postavio/la novu unutarnju vezu na zadatak #%d',
    '%s removed an internal link for the task #%d' => '%s je maknuo/la unutarnju vezu na zadatak #%d',
    'A new internal link for the task #%d has been defined' => 'Nova unutarnja veza na zadatak #%d je postavljena',
    'Internal link removed for the task #%d' => 'unutarnja veza je maknuta za zadatak #%d',
    '%s set a new internal link for the task %s' => '%s je postavio/la novu unutarnju vezu za zadatak %s',
    '%s removed an internal link for the task %s' => '%s je maknuo/la unutarnju vezu za zadatak %s',
    'Automatically set the due date on task creation' => 'Automatski dodaj rok završetka na kreiranom zadatku',
    'Move the task to another column when closed' => 'Makni zadatak u drugi stupac kada je zatvoren',
    'Move the task to another column when not moved during a given period' => 'Makni zadatak u drugi stupac kada ne bude pomaknut određeno vrijeme',
    'Dashboard for %s' => 'Nadzorna ploča za %s',
    'Tasks overview for %s' => 'Pregled zadataka za %s',
    'Subtasks overview for %s' => 'Pregled podzadataka za %s',
    'Projects overview for %s' => 'Pregled projekata za %s',
    'Activity stream for %s' => 'Tijek aktivnosti za %s',
    'Assign a color when the task is moved to a specific swimlane' => 'Dodijeli boju kada je zadatak pomaknut u određenu stazu',
    'Assign a priority when the task is moved to a specific swimlane' => 'Dodijeli prioritet kada je zadatak pomaknut u određenu stazu',
    'User unlocked successfully.' => 'Korisnik je uspješno otključan.',
    'Unable to unlock the user.' => 'Nije moguće otključati korisnika.',
    'Move a task to another swimlane' => 'Pomakni zadatak u drugu stazu',
    'Creator Name' => 'Ime tvorca',
    'Time spent and estimated' => 'Potrošeno i procijenjeno vrijeme',
    'Move position' => 'Promjena pozicije',
    'Move task to another position on the board' => 'Pomakni zadatak na drugu poziciju na ploči',
    'Insert before this task' => 'Umetni prije ovog zadatka',
    'Insert after this task' => 'Umetni poslije ovog zadatka',
    'Unlock this user' => 'Otključaj ovog korisnika',
    'Custom Project Roles' => 'Prilagođne uloge projekta',
    'Add a new custom role' => 'Dodaj novu prilagođenu ulogu',
    'Restrictions for the role "%s"' => 'Ograničenja za ulogu "%s"',
    'Add a new project restriction' => 'Dodaj nova ograničenja na projektu',
    'Add a new drag and drop restriction' => 'Dodaj nova ograničenja za "povuci i spusti"',
    'Add a new column restriction' => 'Dodaj nova ograničenja za stupac',
    'Edit this role' => 'Uredi ovu ulogu',
    'Remove this role' => 'Makni ovu ulogu',
    'There is no restriction for this role.' => 'Nema ograničenja za ovu ulogu.',
    'Only moving task between those columns is permitted' => 'Dozvoljeno micanje zadataka samo među ovim stupcima',
    'Close a task in a specific column when not moved during a given period' => 'Zatvori zadatak u odabranom stupcu kada nema micanja određeno vrijeme',
    'Edit columns' => 'Uredi stupce',
    'The column restriction has been created successfully.' => 'Ograničenje za stupac je uspješno kreiranao.',
    'Unable to create this column restriction.' => 'Nije moguće kreirati ograničenja za stupac.',
    'Column restriction removed successfully.' => 'Ograničenje za stupac je uspješno obrisano.',
    'Unable to remove this restriction.' => 'Nije moguće maknuti ovo ograničenje.',
    'Your custom project role has been created successfully.' => 'Tvoja prilagođena uloga na projektu je uspješno kreirana.',
    'Unable to create custom project role.' => 'Nije moguće kreirati prilagođenu ulogu na projektu.',
    'Your custom project role has been updated successfully.' => 'Tvoja prilagođena uloga na projektu je uspješno dopunjena.',
    'Unable to update custom project role.' => 'Nije moguće dopuniti prilagođenu ulogu na projektu.',
    'Custom project role removed successfully.' => 'Prilagođena uloga na projektu je uspješno maknuta.',
    'Unable to remove this project role.' => 'Nije moguće maknuti ovu ulogu na projektu.',
    'The project restriction has been created successfully.' => 'Ograničenje na projektu je uspješno kreirano.',
    'Unable to create this project restriction.' => 'Nije moguće kreirati ovo ograničenje na projektu.',
    'Project restriction removed successfully.' => 'Ograničenje na projektu je uspješno maknuto.',
    'You cannot create tasks in this column.' => 'Ne možete kreirati zadatak u ovom stupcu.',
    'Task creation is permitted for this column' => 'Kreiranje zadataka u ovom stupcu je zabranjeno',
    'Closing or opening a task is permitted for this column' => 'Zatvaranje ili otvaranje zadatka u ovom stupcu je zabranjeno',
    'Task creation is blocked for this column' => 'Kreiranje zadataka je onemogućeno za ovaj stupac',
    'Closing or opening a task is blocked for this column' => 'Zatvaranje ili otvaranje zadataka u ovom stupcu je onemogućeno',
    'Task creation is not permitted' => 'Kreiranje zadatka nije dozvoljeno',
    'Closing or opening a task is not permitted' => 'Zatvarnaje ili otvaranje zadatka nije dozvoljeno',
    'New drag and drop restriction for the role "%s"' => 'Novo "povuci i spusti" ograničenje za ulogu "%s"',
    'People belonging to this role will be able to move tasks only between the source and the destination column.' => 'Osobe sa ovom ulogom će moći samo micati zadatke između izvornog i odredišnog stupca.',
    'Remove a column restriction' => 'Makni ograničenja za stupac',
    'Do you really want to remove this column restriction: "%s" to "%s"?' => 'Doista želite maknuti ovo ograničenje za stupac: "%s" u "%s"?',
    'New column restriction for the role "%s"' => 'Novo ograničenje za stupac za ulogu "%s"',
    'Rule' => 'Pravilo',
    'Do you really want to remove this column restriction?' => 'Doista želite maknuti ovo ograničenje za stupac?',
    'Custom roles' => 'Prilagođene uloge',
    'New custom project role' => 'Nova prilagođena uloga za projekt',
    'Edit custom project role' => 'Uredi prilagođenu ulogu za projekt',
    'Remove a custom role' => 'Makni prilagođenu ulogu',
    'Do you really want to remove this custom role: "%s"? All people assigned to this role will become project member.' => 'Doista želite maknuti ovu prilagođenu ulogu: "%s"? Sve osobe kojima je dodijeljena ova uloga će postati članovi projekta.',
    'There is no custom role for this project.' => 'Nema prilagođenih uloga za ovaj projekt.',
    'New project restriction for the role "%s"' => 'Novo ograničenje na projektu za ulogu "%s"',
    'Restriction' => 'Ograničenje',
    'Remove a project restriction' => 'Makni ograničenje na projektu',
    'Do you really want to remove this project restriction: "%s"?' => 'Doista želite da maknuti ovo ograničenje na projektu: "%s"?',
    'Duplicate to multiple projects' => 'Dupliraj u više projekata',
    'This field is required' => 'Ovo polje je obavezno',
    'Moving a task is not permitted' => 'Pomicanje zadatka nije dozvoljeno',
    'This value must be in the range %d to %d' => 'Ova vrijednost mora biti u rasponu od %d do %d',
    'You are not allowed to move this task.' => 'Nemate dozvolu za pomicanje ovog zadatka.',
    'API User Access' => 'Pristup korisnika putem API',
    'Preview' => 'Pregled',
    'Write' => 'Upiši',
    'Write your text in Markdown' => 'Upiši tekst u Markdown notaciji',
    'No personal API access token registered.' => 'Nije zabilježen niti jedan pristupni token.',
    'Your personal API access token is "%s"' => 'Vaš osobni API token za pristup je: "%s"',
    'Remove your token' => 'Makni vaš token',
    'Generate a new token' => 'Kreiraj novi token',
    'Showing %d-%d of %d' => 'Prikaži %d-%d od %d',
    'Outgoing Emails' => 'Odlazne e-mail poruke',
    'Add or change currency rate' => 'Dodaj ili promijeni tečaj',
    'Reference currency: %s' => 'Osnovna valuta: %s',
    'Add custom filters' => 'Dodaj prilagođene filtere',
    'Export' => 'Izvezi',
    'Add link label' => 'Dodaj oznaku poveznice',
    'Incompatible Plugins' => 'Nekompatibilni dodaci',
    'Compatibility' => 'Kompatibilnost',
    'Permissions and ownership' => 'Dozvole i vlasništvo',
    'Priorities' => 'Prioriteti',
    'Close this window' => 'Zatvori ovaj prozor',
    'Unable to upload this file.' => 'Nije moguće poslati ovu datoteku.',
    'Import tasks' => 'Uvezi zadatke',
    'Choose a project' => 'Odaberite projekt',
    'Profile' => 'Profil',
    'Application role' => 'Uloga u aplikaciji',
    '%d invitations were sent.' => '%d poslano pozivnica.',
    '%d invitation was sent.' => '%d pozivnica poslana.',
    'Unable to create this user.' => 'Nije moguće kreirati ovog korisnika.',
    'Kanboard Invitation' => 'Kanboard pozivnica',
    'Visible on dashboard' => 'Vidljivo na upravljačkoj ploči',
    'Created at:' => 'Kreirano:',
    'Updated at:' => 'Dopunjeno:',
    'There is no custom filter.' => 'Nema prilagođenih filtera.',
    'New User' => 'Novi korisnik',
    'Authentication' => 'Autorizacija',
    'If checked, this user will use a third-party system for authentication.' => 'Ako je označeno, ovaj korisnik će koristiti vanjski sistem za autorizaciju.',
    'The password is necessary only for local users.' => 'Lozinka je obavezna samo za lokalne korisnike.',
    'You have been invited to register on Kanboard.' => 'Pozvani ste da se registrirate u Kanboard.',
    'Click here to join your team' => 'Kliknite ovdje kako bi se prodružili vašem timu',
    'Invite people' => 'Pozovi ljude',
    'Emails' => 'E-mail-ovi',
    'Enter one email address by line.' => 'Upiši jednu email adresu u redu.',
    'Add these people to this project' => 'Dodaj ove ljude u ovaj projekt',
    'Add this person to this project' => 'Dodaj ovu osobu u ovaj projekt',
    'Sign-up' => 'Registracija',
    'Credentials' => 'Pristupni podaci',
    'New user' => 'Novi korisnik',
    'This username is already taken' => 'Ovo korisničko ime je zauzeto',
    'Your profile must have a valid email address.' => 'Profil mora imati ispravnu email adresu.',
    'TRL - Turkish Lira' => 'TRL - Turska lira',
    'The project email is optional and could be used by several plugins.' => 'e-mail projekta je opcija, a mogi je koristiti i dodaci (plugins).',
    'The project email must be unique across all projects' => 'e-mail projekta mora biti jedinstven za svaki projekt',
    'The email configuration has been disabled by the administrator.' => 'Uređivanje e-mail postavki je onemogućeno od strane administratora.',
    'Close this project' => 'Zatvori ovaj projekt',
    'Open this project' => 'Otvori ovaj projekt',
    'Close a project' => 'Zatvori projekt',
    'Do you really want to close this project: "%s"?' => 'Doista želite zatvoriti projekt: "%s"?',
    'Reopen a project' => 'Ponovo otvori projekt',
    'Do you really want to reopen this project: "%s"?' => 'Doista želite ponovo otvoriti projekt: "%s"?',
    'This project is open' => 'Ovaj projekt je otvoren',
    'This project is closed' => 'Ovaj projekt je zatvoren',
    'Unable to upload files, check the permissions of your data folder.' => 'Nije moguće poslati datoteke, provjerite prava na server folderima.',
    'Another category with the same name exists in this project' => 'Kategorija sa istim imenom već postoji na ovom projektu',
    'Comment sent by email successfully.' => 'Komentar je uspješno poslan e-mail-om.',
    'Sent by email to "%s" (%s)' => 'Poslano na e-mail "%s" (%s)',
    'Unable to read uploaded file.' => 'Nije moguće pročitati poslanu datoteku.',
    'Database uploaded successfully.' => 'Baza podataka je uspješno poslana.',
    'Task sent by email successfully.' => 'Zadatak je uspješno poslan e-mail-om.',
    'There is no category in this project.' => 'Nema kategorija u ovom projektu.',
    'Send by email' => 'Pošalji e-mail-om',
    'Create and send a comment by email' => 'Napravi i pošalji komentar e-mail-om',
    'Subject' => 'Predmet',
    'Upload the database' => 'Pošalji bazu podataka',
    'You could upload the previously downloaded Sqlite database (Gzip format).' => 'Možete poslati prethodno preuzetu Sqlite bazu podataka (Gzip format).',
    'Database file' => 'Datoteka baze podataka',
    'Upload' => 'Pošalji',
    'Your project must have at least one active swimlane.' => 'Projekt mora imati barem jednu aktivnu stazu.',
    'Project: %s' => 'Projekt: %s',
    'Automatic action not found: "%s"' => 'Automatska radnja nije pronađena: "%s"',
    '%d projects' => '%d projekta',
    '%d project' => '%d projekt',
    'There is no project.' => 'Nema projekata.',
    'Sort' => 'Sortiraj',
    'Project ID' => 'RB projekta',
    'Project name' => 'Naziv projekta',
    'Public' => 'Javno',
    'Personal' => 'Osobno',
    '%d tasks' => '%d zadataka',
    '%d task' => '%d zadatak',
    'Task ID' => 'RB zadatka',
    'Assign automatically a color when due date is expired' => 'Automatski postavi boju kada prošao rok završetka',
    'Total score in this column across all swimlanes' => 'Ukupni rezultat u ovom stupcu za sve staze',
    'HRK - Kuna' => 'HRK - Hrvatska Kuna',
    'ARS - Argentine Peso' => 'ARS - Argentiski pezos',
    'COP - Colombian Peso' => 'COP - Kolumbijski pezos',
    '%d groups' => '%d grupe',
    '%d group' => '%d grupa',
    'Group ID' => 'RB grupe',
    'External ID' => 'Vanjski RB',
    '%d users' => '%d korisnika',
    '%d user' => '%d korisnik',
    'Hide subtasks' => 'Sakrij podzadatke',
    'Show subtasks' => 'Prikaži podzadatke',
    'Authentication Parameters' => 'Parametri za autorizaciju',
    'API Access' => 'API pristup',
    'No users found.' => 'Nema ponađenih korisnika.',
    'User ID' => 'RB korisnika',
    'Notifications are activated' => 'Obavijesti su omogućene',
    'Notifications are disabled' => 'Obavijesti su onemogućene',
    'User disabled' => 'Korisnik je onemogućen',
    '%d notifications' => '%d obavjesti',
    '%d notification' => '%d obavijest',
    'There is no external integration installed.' => 'Nema usluga vanjskih servisa.',
    'You are not allowed to update tasks assigned to someone else.' => 'Nemate dozvolu mijenjati zadatke dodijeljene nekom drugom.',
    'You are not allowed to change the assignee.' => 'Nemate dozvolu mijenjati izvršitelja.',
    'Task suppression is not permitted' => 'Suzbijanje zadataka nije dozvoljeno',
    'Changing assignee is not permitted' => 'Promjena izvršitelja nije dozvoljena',
    'Update only assigned tasks is permitted' => 'Dozvoljena je promjena samo dodijeljenih zadataka',
    'Only for tasks assigned to the current user' => 'Samo za zadatke dodijeljene trenutnom korisniku',
    'My projects' => 'Moji projekti',
    'You are not a member of any project.' => 'Niste član niti jednog projekta.',
    'My subtasks' => 'Moji podzadaci',
    '%d subtasks' => '%d podzadataka',
    '%d subtask' => '%d podzadatak',
    'Only moving task between those columns is permitted for tasks assigned to the current user' => 'Premještanje između tih stupaca je dozvoljeno samo za zadatke dodijeljene trenutnom korisniku',
    '[DUPLICATE]' => '[DUPLIKAT]',
    'DKK - Danish Krona' => 'DKK - Danska kruna',
    'Remove user from group' => 'Makni korisnika iz grupe',
    'Assign the task to its creator' => 'Dodijeli zadatak njegovom tvorcu',
    'This task was sent by email to "%s" with subject "%s".' => 'Ovaj zadatak je poslan na email "%s" sa predmetom "%s".',
    'Predefined Email Subjects' => 'Unaprijed definirani e-mail predmeti',
    'Write one subject by line.' => 'Unesite jedan predmet po liniji',
    'Create another link' => 'Napravi još jednu vezu',
    'BRL - Brazilian Real' => 'BRL - Brazilski real',
    'Add a new Kanboard task' => 'Dodajte novi Kanboard zadatak',
    'Subtask not started' => 'Podzadatak nije započeo',
    'Subtask currently in progress' => 'Podzadatak je trenutno u tijeku',
    'Subtask completed' => 'Podzadatak je završen',
    'Subtask added successfully.' => 'Podzadatak je uspješno dodan.',
    '%d subtasks added successfully.' => '%d podzadataka je uspješno dodano.',
    'Enter one subtask by line.' => 'Unesite jedan podzadatak u redu.',
    'Predefined Contents' => 'Unaprijed definirani sadržaj',
    'Predefined contents' => 'Unaprijed definirani sadržaj',
    'Predefined Task Description' => 'Predefinirani opis zadatka',
    'Do you really want to remove this template? "%s"' => 'Doista želite maknuti ovaj predložak? "%s"',
    'Add predefined task description' => 'Dodan predefinirani opis zadatka',
    'Predefined Task Descriptions' => 'Predefinirani opis zadatka',
    'Template created successfully.' => 'Predložak uspješno kreiran',
    'Unable to create this template.' => 'Nije moguće kreirati ovaj predložak',
    'Template updated successfully.' => 'Predložak uspješno dopunjen',
    'Unable to update this template.' => 'Nije moguće dopuniti ovaj predložak',
    'Template removed successfully.' => 'Predložak uspješno maknut',
    'Unable to remove this template.' => 'Nije moguće maknuti ovaj predložak',
    'Template for the task description' => 'Predložak za opis zadatka',
    'The start date is greater than the end date' => 'Početni datum je veći od kranjeg datuma',
    'Tags must be separated by a comma' => 'Oznake moraju biti razdvojene zarezom',
    'Only the task title is required' => 'Samo naslov zadatka je obavezan',
    'Creator Username' => 'Korisničko ime tvorca',
    'Color Name' => 'Boja stupca',
    'Column Name' => 'Naziv stupca',
    'Swimlane Name' => 'Naziv staze',
    'Time Estimated' => 'Procijenjeno vrijeme',
    'Time Spent' => 'Potrošeno vrijeme',
    'External Link' => 'Vanjska veza',
    'This feature enables the iCal feed, RSS feed and the public board view.' => 'Ova funkcionalnost omogućava iCal kanal, RSS kanal i javni prikaz ploče.',
    'Stop the timer of all subtasks when moving a task to another column' => 'Zaustavi timer na svim podzadacima prilikom premještanja zadatka u drugi stupac',
    'Subtask Title' => 'Naslov podzadatka',
    'Add a subtask and activate the timer when moving a task to another column' => 'Dodaj podzadatak i aktiviraj timer prilikom micanja zadatka u drugi stupac',
    'days' => 'dana',
    'minutes' => 'minuta',
    'seconds' => 'sekundi',
    'Assign automatically a color when preset start date is reached' => 'Automatski postavi boju kada se dosegne unaprijed zadani datum početka',
    'Move the task to another column once a predefined start date is reached' => 'Premjesti zadatak u drugi stupac kada se dosegne unaprijed zadani datum početka',
    'This task is now linked to the task %s with the relation "%s"' => 'Zadatak je sada povezan sa zadatkom %s relacijom "%s"',
    'The link with the relation "%s" to the task %s has been removed' => 'Veza sa relacijom "%s" na zadatak %s je maknuta',
    'Custom Filter:' => 'Prilagođeni filter',
    'Unable to find this group.' => 'Nije moguće pronaći ovu grupu.',
    '%s moved the task #%d to the column "%s"' => '%s je pomaknuo/la zadatak #%d u stupac "%s"',
    '%s moved the task #%d to the position %d in the column "%s"' => '%s je pmaknuo/la zadatak #%d na poziciju %d u stupcu "%s"',
    '%s moved the task #%d to the swimlane "%s"' => '%s je pomaknuo/la zadatak #%d u stazu "%s"',
    '%sh spent' => '%ss potrošeno',
    '%sh estimated' => '%ss procijenjeno',
    'Select All' => 'Označi sve',
    'Unselect All' => 'Poništi odabir svega',
    'Apply action' => 'Primjeni radnju',
    'Move selected tasks to another column or swimlane' => 'Pomakni odabrani zadatak u neki drugi stupac',
    'Edit tasks in bulk' => 'Masovno uređivanje zadataka',
    'Choose the properties that you would like to change for the selected tasks.' => 'Izaberite svojstva koja želite promijeniti na izabranim zadacima.',
    'Configure this project' => 'Uredite ovaj projekt',
    'Start now' => 'Započni sada',
    '%s removed a file from the task #%d' => '%s je maknuo/la dataoteku sa zadatka #%d',
    'Attachment removed from task #%d: %s' => 'Privitak je maknut sa zadatka #%d: %s',
    'No color' => 'Bez boje',
    'Attachment removed "%s"' => 'Privitak maknut "%s"',
    '%s removed a file from the task %s' => '%s je maknuo/la datoteku sa zadatka %s',
    'Move the task to another swimlane when assigned to a user' => 'Premjesti zadatak u drugu stazu kada je zadatak dodijeljen korisniku',
    'Destination swimlane' => 'Odredišna staza',
    'Assign a category when the task is moved to a specific swimlane' => 'Postavi kategoriju kada je zadatak premješten u određenu stazu',
    'Move the task to another swimlane when the category is changed' => 'Pomakni zadatak u drugu stazu kada se promijeni kategorija',
    'Reorder this column by priority (ASC)' => 'Presloži ovaj stupac po prioritetu (UZLAZNO)',
    'Reorder this column by priority (DESC)' => 'Presloži ovaj stupac po prioritetu (SILAZNO)',
    'Reorder this column by assignee and priority (ASC)' => 'Presloži ovaj stupac po izvršitelju (UZLAZNO)',
    'Reorder this column by assignee and priority (DESC)' => 'Presloži ovaj stupac po izvršitelju (SILAZNO)',
    'Reorder this column by assignee (A-Z)' => 'Presloži ovaj stupac po izvršitelju (A-Ž)',
    'Reorder this column by assignee (Z-A)' => 'Presloži ovaj stupac po izvršitelju (Ž-A)',
    'Reorder this column by due date (ASC)' => 'Presloži ovaj stupac po roku završetka (UZLAZNO)',
    'Reorder this column by due date (DESC)' => 'Presloži ovaj stupac po roku završetka (SILAZNO)',
    'Reorder this column by id (ASC)' => 'Poredaj stupac po id-u (ASC)',
    'Reorder this column by id (DESC)' => 'Poredaj stupac po id-u (DESC)',
    '%s moved the task #%d "%s" to the project "%s"' => '%s je premjestio/la zadatak #%d "%s" u projekt "%s"',
    'Task #%d "%s" has been moved to the project "%s"' => 'Zadatak #%d "%s" je premješten u projekt "%s"',
    'Move the task to another column when the due date is less than a certain number of days' => 'Pomakni zadatak u drugi stupac kada je datum roka završetka kraći od određenog broja dana',
    'Automatically update the start date when the task is moved away from a specific column' => 'Automatski dopuni datum početka kada se zadatak pomakne iz određenog stupca',
    'HTTP Client:' => 'HTTP klijent',
    'Assigned' => 'Dodijeljeno',
    'Task limits apply to each swimlane individually' => 'Ograničenje broja zadataka vrijedi za svaku stazu zasebno',
    'Column task limits apply to each swimlane individually' => 'Ograničenje broja zadataka u stupcu je za svaku stazu posebno',
    'Column task limits are applied to each swimlane individually' => 'Ograničenje broja zadataka u stupcu se primjenjuje za svaku stazu posebno',
    'Column task limits are applied across swimlanes' => 'Ograničenje broja zadataka u stupcu je po svim stazama',
    'Task limit: ' => 'Ograničenje broja zadataka: ',
    'Change to global tag' => 'Promijeni u globalnu oznaku',
    'Do you really want to make the tag "%s" global?' => 'Doista želite da oznaka "%s" postane globalna?',
    'Enable global tags for this project' => 'Omogući globalne oznake za ovaj projekt',
    'Group membership(s):' => 'Članstvo u grupama:',
    '%s is a member of the following group(s): %s' => '%s je član grupa: %s',
    '%d/%d group(s) shown' => '%d/%d prikazane grupe',
    'Subtask creation or modification' => 'Kreiranje ili promjena podzadatka',
    'Assign the task to a specific user when the task is moved to a specific swimlane' => 'Dodijeli zadatak određenom korisniku kada je zadatak premješten u određenu stazu',
    'Comment' => 'Komentar',
    'Collapse vertically' => 'Skupi vertikalno',
    'Expand vertically' => 'Proširi vertikalno',
    'MXN - Mexican Peso' => 'MXN - Meksički pezos',
    'Estimated vs actual time per column' => 'Procijenjeno u odnosu na stvarno vrijeme po stupcu',
    'HUF - Hungarian Forint' => 'HUD - Mađarska forinta',
    'XBT - Bitcoin' => 'XBT - Bitcoin',
    'You must select a file to upload as your avatar!' => 'Morate odabrati datoteku za prijenos kao svoj avatar!',
    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Datoteka koju ste prenijeli nije važeća slika! (Dopušteni su samo *.gif, *.jpg, *.jpeg i *.png!)',
    'Automatically set the due date when the task is moved away from a specific column' => 'Automatski postavite datum dospijeća kada se zadatak premjesti iz određenog stupca',
    'No other projects found.' => 'Nema pronađenih drugih projekata.',
    'Tasks copied successfully.' => 'Zadaci uspješno kopirani.',
    'Unable to copy tasks.' => 'Nije moguće kopirati zadatke.',
    'Theme' => 'Tema',
    'Theme:' => 'Tema:',
    'Light theme' => 'Svijetla tema',
    'Dark theme' => 'Tamna tema',
    'Automatic theme - Sync with system' => 'Automatska tema - Sinkronizacija sa sustavom',
    'Application managers or more' => 'Voditelji aplikacija ili više',
    'Administrators' => 'Administratori',
    'Visibility:' => 'Vidljivost:',
    'Standard users' => 'Standardni korisnici',
    'Visibility is required' => 'Vidljivost je obavezna',
    'The visibility should be an app role' => 'Vidljivost bi trebala biti uloga aplikacije',
    'Reply' => 'Odgovori',
    '%s wrote: ' => '%s napisao: ',
    'Number of visible tasks in this column and swimlane' => 'Broj vidljivih zadataka u ovom stupcu i plivačkoj stazi',
    'Number of tasks in this swimlane' => 'Broj zadataka u ovoj plivačkoj stazi',
    'Unable to find another subtask in progress, you can close this window.' => 'Nije moguće pronaći drugi podzadatak u tijeku, možete zatvoriti ovaj prozor.',
    'This theme is invalid' => 'Ova tema je nevažeća',
    'This role is invalid' => 'Ova uloga je nevažeća',
    'This timezone is invalid' => 'Ova vremenska zona je nevažeća',
    'This language is invalid' => 'Ovaj jezik je nevažeći',
    'This URL is invalid' => 'Ovaj URL je nevažeći',
    'Date format invalid' => 'Format datuma nevažeći',
    'Time format invalid' => 'Format vremena nevažeći',
    'Invalid Mail transport' => 'Nevažeći transport pošte',
    'Color invalid' => 'Boja nevažeća',
    'This value must be greater or equal to %d' => 'Ova vrijednost mora biti veća ili jednaka %d',
    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Dodajte BOM na početak datoteke (obavezno za Microsoft Excel)',
    'Just add these tag(s)' => 'Samo dodajte ove oznake',
    'Remove internal link(s)' => 'Uklonite unutarnje poveznice',
    'Import tasks from another project' => 'Uvezite zadatke iz drugog projekta',
    'Select the project to copy tasks from' => 'Odaberite projekt iz kojeg želite kopirati zadatke',
    'The total maximum allowed attachments size is %sB.' => 'Ukupna maksimalna dopuštena veličina privitaka je %sB.',
    'Add attachments' => 'Dodaj privitke',
    'Task #%d "%s" is overdue' => 'Zadatak #%d "%s" je istekao',
    'Enable notifications by default for all new users' => 'Omogući obavijesti prema zadanim postavkama za sve nove korisnike',
    'Assign the task to its creator for specific columns if no assignee is set manually' => 'Dodijeli zadatak njegovom kreatoru za određene stupce ako izvršitelj nije ručno postavljen',
    'Assign a task to the logged user on column change to specified column if no user is assigned' => 'Dodijeli zadatak prijavljenom korisniku pri promjeni stupca na zadani stupac ako nitko nije dodijeljen',
];
